@@ -976,6 +976,23 @@ is_rings_available(amdgpu_device_handle device_handle, uint32_t mask,
 	return  hw_ip_info.available_rings & mask;
 }
 
+void asic_userq_readiness(amdgpu_device_handle device_handle, bool arr[AMD_IP_MAX])
+{
+	int r, i;
+	enum amd_ip_block_type ip;
+	struct drm_amdgpu_info_device dev_info = {0};
+
+	r = amdgpu_query_info(device_handle, AMDGPU_INFO_DEV_INFO,
+			      sizeof(dev_info), &dev_info);
+	igt_assert_eq(r, 0);
+
+	if (!dev_info.userq_ip_mask)
+		return;
+
+	for (i = 0, ip = AMD_IP_GFX; ip < AMD_IP_MAX; ip++)
+		arr[i++] = dev_info.userq_ip_mask & (1 << ip);
+}
+
 /**
  * asic_rings_readness:
  * @device handle: handle to driver internal information
@@ -1022,6 +1039,7 @@ is_reset_enable(enum amd_ip_block_type ip_type, uint32_t reset_type, const struc
 	char cmd[256];
 	FILE *fp;
 	char buffer[128];
+	char buffer2[128];
 
 	char *token, *buf;
 	char reset_mask[32];
@@ -1032,6 +1050,10 @@ is_reset_enable(enum amd_ip_block_type ip_type, uint32_t reset_type, const struc
 		snprintf(reset_mask, sizeof(reset_mask) - 1, "gfx_reset_mask");
 	else if (ip_type == AMD_IP_COMPUTE)
 		snprintf(reset_mask, sizeof(reset_mask) - 1, "compute_reset_mask");
+	else if (ip_type == AMD_IP_VCN_UNIFIED)
+		snprintf(reset_mask, sizeof(reset_mask) - 1, "vcn_reset_mask");
+	else if (ip_type == AMD_IP_VCN_JPEG)
+		snprintf(reset_mask, sizeof(reset_mask) - 1, "jpeg_reset_mask");
 	else
 		snprintf(reset_mask, sizeof(reset_mask) - 1, "sdma_reset_mask");
 
@@ -1047,6 +1069,7 @@ is_reset_enable(enum amd_ip_block_type ip_type, uint32_t reset_type, const struc
 	buf = fgets(buffer, sizeof(buffer)-1, fp);
 
 	if (buf != NULL) {
+		strcpy(buffer2, buffer);
 		token = strtok(buf, " \n");
 		while (token != NULL) {
 			for (i = 0; reset_arr[i].name != NULL; i++) {
@@ -1062,11 +1085,12 @@ is_reset_enable(enum amd_ip_block_type ip_type, uint32_t reset_type, const struc
 		igt_kmsg("***FAILURE fgets %s LINE %d FILE %s\n",
 				buffer, __LINE__, __FILE__);
 	}
-	if (mask == reset_type)
+	if (mask & reset_type)
 		enable = true;
 	else
-		igt_kmsg("***FAILURE mask found 0x%x requested 0x%x operation is not supported LINE %d FILE %s\n",
-				mask, reset_type, __LINE__, __FILE__);
+		igt_kmsg("***FAILURE mask found 0x%x(%s) requested 0x%x operation %s is not supported LINE %d FILE %s\n",
+				mask, buffer2, reset_type, ip_type == AMD_IP_GFX ? "GFX": ip_type == AMD_IP_COMPUTE ? "COMPUTE" : "SDMA",
+						__LINE__, __FILE__);
 
 	pclose(fp);
 
