@@ -27,6 +27,11 @@
 #define AMDGPU_RESET_TYPE_PER_QUEUE (1 << 2) /* per queue */
 #define AMDGPU_RESET_TYPE_PER_PIPE (1 << 3) /* per pipe */
 
+/* User queue */
+#define   S_3F3_INHERIT_VMID_MQD_GFX(x)        (((unsigned int)(x)&0x1) << 22)/* userqueue only */
+#define   S_3F3_VALID_COMPUTE(x)		(((unsigned int)(x)&0x1) << 23)/* userqueue only */
+#define   S_3F3_INHERIT_VMID_MQD_COMPUTE(x)	(((unsigned int)(x)&0x1) << 30)/* userqueue only */
+
 enum amd_ip_block_type {
 	AMD_IP_GFX = 0,
 	AMD_IP_COMPUTE,
@@ -86,6 +91,14 @@ struct dynamic_test{
 	bool support_sdma;
 };
 
+struct amdgpu_userq_bo {
+	amdgpu_bo_handle handle;
+	amdgpu_va_handle va_handle;
+	uint64_t mc_addr;
+	uint64_t size;
+	void *ptr;
+};
+
 #define for_each_test(t, T) for(typeof(*T) *t = T; t->name; t++)
 
 /* set during execution */
@@ -105,6 +118,7 @@ struct amdgpu_ring_context {
 	uint32_t *pm4;		/* data of the packet */
 	uint32_t pm4_size;	/* max allocated packet size */
 	bool secure;		/* secure or not */
+	uint32_t priority;	/* user queue priority */
 
 	uint64_t bo_mc;		/* GPU address of first buffer */
 	uint64_t bo_mc2;	/* GPU address for p4 packet */
@@ -141,6 +155,29 @@ struct amdgpu_ring_context {
 	struct amdgpu_cs_ib_info ib_info;     /* amdgpu_bo_list_create */
 	struct amdgpu_cs_request ibs_request; /* amdgpu_cs_query_fence_status */
 	struct amdgpu_cs_err_codes err_codes;
+
+	/* User queue resources */
+	struct  amdgpu_userq_bo queue;
+	struct  amdgpu_userq_bo shadow;
+	struct  amdgpu_userq_bo doorbell;
+	struct  amdgpu_userq_bo rptr;
+	struct  amdgpu_userq_bo wptr;
+	struct  amdgpu_userq_bo csa;
+	struct  amdgpu_userq_bo eop;
+
+	uint32_t *queue_cpu;
+	uint64_t *wptr_cpu;
+	uint64_t *doorbell_cpu;
+
+	uint32_t db_handle;
+	uint32_t queue_id;
+
+	uint32_t timeline_syncobj_handle;
+	uint64_t point;
+	bool user_queue;
+	uint64_t time_out;
+
+	struct drm_amdgpu_info_uq_fw_areas info;
 };
 
 
@@ -232,6 +269,8 @@ amdgpu_open_devices(bool open_render_node, int max_cards_supported, int drm_amdg
 void
 asic_rings_readness(amdgpu_device_handle device_handle, uint32_t mask, bool arr[AMD_IP_MAX]);
 
+void asic_userq_readiness(amdgpu_device_handle device_handle, bool arr[AMD_IP_MAX]);
+
 bool
 is_reset_enable(enum amd_ip_block_type ip_type, uint32_t reset_type, const struct pci_addr *pci);
 
