@@ -86,7 +86,9 @@
 #define igt_assume(e) BUILD_BUG_ON_INVALID(e)
 #endif
 
+#ifndef __noreturn
 #define __noreturn __attribute__((noreturn))
+#endif
 #define __maybe_unused __attribute__((unused))
 
 extern const char* __igt_test_description __attribute__((weak));
@@ -380,6 +382,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
 	__igt_dynamic_f(igt_unique(__tmpchar), f)
 
 const char *igt_subtest_name(void);
+const char *igt_dynamic_subtest_name(void);
 bool igt_only_list_subtests(void);
 
 void __igt_subtest_group_save(int *, int *);
