@@ -495,58 +495,6 @@ igt_intel_driver_load(const char *opts, const char *driver)
 	return 0;
 }
 
-/**
- * kick_snd_hda_intel:
- *
- * This function unbinds the snd_hda_intel driver so the module can be
- * unloaded.
- *
- */
-static void kick_snd_hda_intel(void)
-{
-	DIR *dir;
-	struct dirent *snd_hda;
-	int fd; size_t len;
-
-	const char *dpath = "/sys/bus/pci/drivers/snd_hda_intel";
-	const char *path = "/sys/bus/pci/drivers/snd_hda_intel/unbind";
-	const char *devid = "0000:";
-
-	fd = open(path, O_WRONLY);
-	if (fd < 0) {
-		return;
-	}
-
-	dir = opendir(dpath);
-	if (!dir)
-		goto out;
-
-	len = strlen(devid);
-	while ((snd_hda = readdir(dir))) {
-		struct stat st;
-		char fpath[PATH_MAX];
-
-		if (*snd_hda->d_name == '.')
-			continue;
-
-		snprintf(fpath, sizeof(fpath), "%s/%s", dpath, snd_hda->d_name);
-		if (lstat(fpath, &st))
-			continue;
-
-		if (!S_ISLNK(st.st_mode))
-			continue;
-
-		if (!strncmp(devid, snd_hda->d_name, len)) {
-			igt_ignore_warn(write(fd, snd_hda->d_name,
-					strlen(snd_hda->d_name)));
-		}
-	}
-
-	closedir(dir);
-out:
-	close(fd);
-}
-
 static int igt_always_unload_audio_driver(char **who)
 {
 	int ret;
@@ -579,7 +527,9 @@ static int igt_always_unload_audio_driver(char **who)
 			ret = pipewire_pulse_start_reserve();
 			if (ret)
 				igt_warn("Failed to notify pipewire_pulse\n");
-			kick_snd_hda_intel();
+
+			igt_kmod_unbind("snd_hda_intel", NULL);
+
 			ret = igt_kmod_unload(*m);
 			pipewire_pulse_stop_reserve();
 			if (ret) {
@@ -633,7 +583,7 @@ int __igt_intel_driver_unload(char **who, const char *driver)
 	}
 
 	if (igt_kmod_is_loaded(driver)) {
-		igt_kmod_unbind(driver);
+		igt_kmod_unbind(driver, NULL);
 
 		ret = igt_kmod_unload(driver);
 		if (ret) {
@@ -647,10 +597,12 @@ int __igt_intel_driver_unload(char **who, const char *driver)
 	return 0;
 }
 
-/*
- * Unbind driver from devices. Currently supports only PCI bus
+/**
+ * igt_kmod_unbind: Unbind driver from devices. Currently supports only PCI bus
+ * @mod_name: name of the module to unbind
+ * @pci_device: if provided, unbind only this device, otherwise unbind all devices
  */
-int igt_kmod_unbind(const char *mod_name)
+int igt_kmod_unbind(const char *mod_name, const char *pci_device)
 {
 	char path[PATH_MAX];
 	struct dirent *de;
@@ -663,29 +615,67 @@ int igt_kmod_unbind(const char *mod_name)
 
 	dir = opendir(path);
 
-	/* Module may be loaded, but without any device bound */
+	/* Module not loaded, nothing to unbind */
 	if (!dir)
 		return 0;
 
 	while ((de = readdir(dir))) {
-		int devfd;
 		bool ret;
 
 		if (de->d_type != DT_LNK || !isdigit(de->d_name[0]))
 			continue;
 
-		devfd = openat(dirfd(dir), de->d_name, O_RDONLY | O_CLOEXEC);
-		igt_assert(devfd >= 0);
+		if (pci_device && strcmp(pci_device, de->d_name) != 0)
+			continue;
 
-		ret = igt_sysfs_set(devfd, "driver/unbind", de->d_name);
+		ret = igt_sysfs_set(dirfd(dir), "unbind", de->d_name);
 		igt_assert(ret);
-
-		close(devfd);
 	}
 
+	closedir(dir);
+
 	return 0;
 }
 
+/**
+ * igt_kmod_bind: Bind driver to device
+ * @mod_name: name of the module to rebind
+ * @pci_device: device to bind
+ *
+ * Module should already be loaded
+ */
+int igt_kmod_bind(const char *mod_name, const char *pci_device)
+{
+	char path[PATH_MAX];
+	int dirlen, dirfd;
+	int ret;
+
+	dirlen = snprintf(path, sizeof(path), "/sys/module/%s/drivers/pci:%s/",
+			  mod_name, mod_name);
+	igt_assert(dirlen < sizeof(path));
+
+	dirfd = open(path, O_RDONLY | O_CLOEXEC);
+	if (dirfd < 0)
+		return dirfd;
+
+	ret = igt_sysfs_set(dirfd, "bind", pci_device);
+
+	close(dirfd);
+
+	return ret;
+}
+
+/**
+ * igt_kmod_rebind: Unbind driver from devices and bind it again
+ * @mod_name: name of the module to rebind
+ * @pci_device: device to rebind to
+ */
+int igt_kmod_rebind(const char *mod_name, const char *pci_device)
+{
+	return igt_kmod_unbind(mod_name, pci_device) ||
+		igt_kmod_bind(mod_name, pci_device);
+}
+
 /**
  * igt_intel_driver_unload:
  *
@@ -718,7 +708,7 @@ igt_intel_driver_unload(const char *driver)
 
 int igt_xe_driver_unload(void)
 {
-	igt_kmod_unbind("xe");
+	igt_kmod_unbind("xe", NULL);
 
 	igt_kmod_unload("xe");
 	if (igt_kmod_is_loaded("xe"))
