@@ -65,5 +65,9 @@ void syncobj_timeline_to_timeline(int fd,
 				  uint64_t timeline_src, uint32_t point_src);
 void syncobj_timeline_signal(int fd, uint32_t *handles, uint64_t *points,
 			     uint32_t count);
+int __syncobj_eventfd(int fd, uint32_t handle, uint64_t point, uint32_t flags,
+		      int ev_fd);
+void syncobj_eventfd(int fd, uint32_t handle, uint64_t point, uint32_t flags,
+		     int ev_fd);
 
 #endif /* IGT_SYNCOBJ_H */
