@@ -21,7 +21,6 @@
 
 #define BITRANGE(start, end) (end - start + 1)
 #define GET_CMDS_INFO(__fd) intel_get_cmds_info(intel_get_drm_devid(__fd))
-#define MEM_COPY_MOCS_SHIFT                     25
 
 /* Blitter tiling definitions sanity checks */
 static_assert(T_LINEAR == I915_TILING_NONE, "Linear definitions have to match");
@@ -1115,7 +1114,13 @@ int blt_block_copy(int fd,
 	return ret;
 }
 
-static uint16_t __ccs_size(int fd, const struct blt_ctrl_surf_copy_data *surf)
+/*
+ * Function calculates CCS bytes used for the surface. Size field in
+ * ctrl-surf-copy command struct is for Xe and Xe2 10-bit length, so caller
+ * has to divide ccs copy of bigger surfaces to couple of separate commands.
+ * This function returns total size of ccs data used for the surface.
+ */
+static uint32_t __ccs_size(int fd, const struct blt_ctrl_surf_copy_data *surf)
 {
 	uint32_t src_size, dst_size;
 	uint16_t ccsratio = CCS_RATIO(fd);
@@ -1286,8 +1291,8 @@ uint64_t emit_blt_ctrl_surf_copy(int fd,
 	uint64_t dst_offset, src_offset, bb_offset, alignment;
 	uint32_t bbe = MI_BATCH_BUFFER_END;
 	uint32_t *bb;
-	uint16_t num_ccs_blocks = (ip_ver >= IP_VER(20, 0)) ?
-				(xe_get_default_alignment(fd) / CCS_RATIO(fd)) : CCS_RATIO(fd);
+	uint32_t ccs_per_page, max_blocks, src_step, dst_step;
+	int32_t left_blocks;
 
 	igt_assert_f(ahnd, "ctrl-surf-copy supports softpin only\n");
 	igt_assert_f(surf, "ctrl-surf-copy requires data to do ctrl-surf-copy blit\n");
@@ -1299,51 +1304,108 @@ uint64_t emit_blt_ctrl_surf_copy(int fd,
 					  alignment, surf->dst.pat_index);
 	bb_offset = get_offset(ahnd, surf->bb.handle, surf->bb.size, alignment);
 
+	bb = bo_map(fd, surf->bb.handle, surf->bb.size, surf->driver);
+
+	/*
+	 * Copying in/out CCS data is limited by bitfield size_of_ctrl_copy size
+	 * what means operation on bigger surface needs to be handled on couple
+	 * of ctrl-surf-copy commands.
+	 *
+	 * Instead of hardcoding maximum number of blocks copied in single
+	 * command we may calculate it from bitfield size (Xe and Xe2 differs
+	 * in bitfield location [and in future platforms potentially size]).
+	 */
 	if (ip_ver >= IP_VER(20, 0)) {
+		ccs_per_page = SZ_4K / CCS_RATIO(fd);
+
 		data.xe2.dw00.client = 0x2;
 		data.xe2.dw00.opcode = 0x48;
 		data.xe2.dw00.src_access_type = surf->src.access_type;
 		data.xe2.dw00.dst_access_type = surf->dst.access_type;
-
-		/* Ensure dst has size capable to keep src ccs aux */
-		data.xe2.dw00.size_of_ctrl_copy = __ccs_size(fd, surf) / num_ccs_blocks - 1;
 		data.xe2.dw00.length = 0x3;
 
-		data.xe2.dw01.src_address_lo = src_offset;
-		data.xe2.dw02.src_address_hi = src_offset >> 32;
-		data.xe2.dw02.src_mocs_index = surf->src.mocs_index;
+		data.xe2.dw00.size_of_ctrl_copy = -1;
+		max_blocks = data.xe2.dw00.size_of_ctrl_copy + 1;
 
-		data.xe2.dw03.dst_address_lo = dst_offset;
-		data.xe2.dw04.dst_address_hi = dst_offset >> 32;
+		/*
+		 * For Xe2+ each size_of_ctrl_copy increment covers 4K page size
+		 * of surface, which in turn is covered by 8B of CCS data.
+		 */
+		src_step = surf->src.access_type == DIRECT_ACCESS ? ccs_per_page : SZ_4K;
+		src_step *= max_blocks;
+		dst_step = surf->dst.access_type == DIRECT_ACCESS ? ccs_per_page : SZ_4K;
+		dst_step *= max_blocks;
+
+		data.xe2.dw02.src_mocs_index = surf->src.mocs_index;
 		data.xe2.dw04.dst_mocs_index = surf->dst.mocs_index;
 
 		data_sz = sizeof(data.xe2);
 	} else {
+		ccs_per_page = SZ_64K / CCS_RATIO(fd);
+
 		data.gen12.dw00.client = 0x2;
 		data.gen12.dw00.opcode = 0x48;
 		data.gen12.dw00.src_access_type = surf->src.access_type;
 		data.gen12.dw00.dst_access_type = surf->dst.access_type;
-
-		/* Ensure dst has size capable to keep src ccs aux */
-		data.gen12.dw00.size_of_ctrl_copy = __ccs_size(fd, surf) / num_ccs_blocks - 1;
 		data.gen12.dw00.length = 0x3;
 
-		data.gen12.dw01.src_address_lo = src_offset;
-		data.gen12.dw02.src_address_hi = src_offset >> 32;
-		data.gen12.dw02.src_mocs_index = surf->src.mocs_index;
+		data.gen12.dw00.size_of_ctrl_copy = -1;
+		max_blocks = data.gen12.dw00.size_of_ctrl_copy + 1;
 
-		data.gen12.dw03.dst_address_lo = dst_offset;
-		data.gen12.dw04.dst_address_hi = dst_offset >> 32;
+		/*
+		 * For Xe each size_of_ctrl_copy increment covers 64K page size
+		 * of surface, which in turn is covered by 256B of CCS data.
+		 */
+		src_step = surf->src.access_type == DIRECT_ACCESS ? ccs_per_page : SZ_64K;
+		src_step *= max_blocks;
+		dst_step = surf->dst.access_type == DIRECT_ACCESS ? ccs_per_page : SZ_64K;
+		dst_step *= max_blocks;
+
+		data.gen12.dw02.src_mocs_index = surf->src.mocs_index;
 		data.gen12.dw04.dst_mocs_index = surf->dst.mocs_index;
 
 		data_sz = sizeof(data.gen12);
 	}
 
-	bb = bo_map(fd, surf->bb.handle, surf->bb.size, surf->driver);
+	left_blocks = __ccs_size(fd, surf) / ccs_per_page;
 
-	igt_assert(bb_pos + data_sz < surf->bb.size);
-	memcpy(bb + bb_pos, &data, data_sz);
-	bb_pos += data_sz;
+	while (left_blocks > 0) {
+		int32_t nblocks = min_t(int32_t, left_blocks, max_blocks);
+
+		if (ip_ver >= IP_VER(20, 0)) {
+			data.xe2.dw00.size_of_ctrl_copy = nblocks - 1;
+			data.xe2.dw01.src_address_lo = src_offset;
+			data.xe2.dw02.src_address_hi = src_offset >> 32;
+			data.xe2.dw03.dst_address_lo = dst_offset;
+			data.xe2.dw04.dst_address_hi = dst_offset >> 32;
+		} else {
+			data.gen12.dw00.size_of_ctrl_copy = nblocks - 1;
+			data.gen12.dw01.src_address_lo = src_offset;
+			data.gen12.dw02.src_address_hi = src_offset >> 32;
+			data.gen12.dw03.dst_address_lo = dst_offset;
+			data.gen12.dw04.dst_address_hi = dst_offset >> 32;
+		}
+
+		left_blocks -= max_blocks;
+		dst_offset += dst_step;
+		src_offset += src_step;
+
+		igt_assert(bb_pos + data_sz < surf->bb.size);
+		memcpy(bb + bb_pos, &data, data_sz);
+		bb_pos += data_sz;
+
+		if (surf->print_bb) {
+			igt_info("[CTRL SURF]:\n");
+			igt_info("src offset: 0x%" PRIx64 ", dst offset: 0x%" PRIx64
+				 ", bb offset: 0x%" PRIx64 ", copy nblocks: 0x%x\n",
+				 src_offset, dst_offset, bb_offset, nblocks);
+
+			if (ip_ver >= IP_VER(20, 0))
+				xe2_dump_bb_surf_ctrl_cmd(&data.xe2);
+			else
+				dump_bb_surf_ctrl_cmd(&data.gen12);
+		}
+	}
 
 	if (emit_bbe) {
 		igt_assert(bb_pos + sizeof(uint32_t) < surf->bb.size);
@@ -1351,18 +1413,6 @@ uint64_t emit_blt_ctrl_surf_copy(int fd,
 		bb_pos += sizeof(uint32_t);
 	}
 
-	if (surf->print_bb) {
-		igt_info("[CTRL SURF]:\n");
-		igt_info("src offset: %" PRIx64 ", dst offset: %" PRIx64
-			 ", bb offset: %" PRIx64 "\n",
-			 src_offset, dst_offset, bb_offset);
-
-		if (ip_ver >= IP_VER(20, 0))
-			xe2_dump_bb_surf_ctrl_cmd(&data.xe2);
-		else
-			dump_bb_surf_ctrl_cmd(&data.gen12);
-	}
-
 	munmap(bb, surf->bb.size);
 
 	return bb_pos;
@@ -1748,53 +1798,242 @@ int blt_fast_copy(int fd,
 	return ret;
 }
 
+struct xe_mem_copy_data {
+	struct {
+		uint32_t length:			BITRANGE(0, 7);
+		uint32_t compression_format:	BITRANGE(8, 12);
+		uint32_t compression_enable:	BITRANGE(13, 13);
+		uint32_t rsvd0:			BITRANGE(14, 14);
+		uint32_t dst_compressible:	BITRANGE(15, 15);
+		uint32_t src_compressible:	BITRANGE(16, 16);
+		uint32_t copy_type:		BITRANGE(17, 18);
+		uint32_t mode:			BITRANGE(19, 19);
+		uint32_t rsvd1:			BITRANGE(20, 21);
+		uint32_t opcode:			BITRANGE(22, 28);
+		uint32_t client:			BITRANGE(29, 31);
+	} dw00;
+
+	struct {
+		union {
+			struct {
+				uint32_t width:			BITRANGE(0, 17);
+				uint32_t rsvd0:			BITRANGE(18, 31);
+			} byte_copy;
+			struct {
+				uint32_t width:			BITRANGE(0, 23);
+				uint32_t rsvd0:			BITRANGE(24, 31);
+			} page_copy;
+			uint32_t val;
+		};
+	} dw01;
+
+	struct {
+		uint32_t height:			BITRANGE(0, 17);
+		uint32_t rsvd0:			BITRANGE(18, 31);
+	} dw02;
+
+	struct {
+		uint32_t src_pitch:		BITRANGE(0, 17);
+		uint32_t rsvd0:			BITRANGE(18, 31);
+	} dw03;
+
+	struct {
+		uint32_t dst_pitch:		BITRANGE(0, 17);
+		uint32_t rsvd0:			BITRANGE(18, 31);
+	} dw04;
+
+	struct {
+		uint32_t src_address_lo;
+	} dw05;
+
+	struct {
+		uint32_t src_address_hi;
+	} dw06;
+
+	struct {
+		uint32_t dst_address_lo;
+	} dw07;
+
+	struct {
+		uint32_t dst_address_hi;
+	} dw08;
+
+	struct {
+		uint32_t dst_mocs:		BITRANGE(0, 6);
+		uint32_t rsvd0:			BITRANGE(7, 24);
+		uint32_t src_mocs:		BITRANGE(25, 31);
+	} dw09;
+};
+
 /**
- * blt_mem_init:
+ * blt_mem_copy_init:
  * @fd: drm fd
  * @mem: structure for initialization
+ * @mode: copy mode - byte or page (256B)
+ * @copy_type: linear or matrix
  *
  * Function is zeroing @mem and sets fd and driver fields (INTEL_DRIVER_I915 or
  * INTEL_DRIVER_XE).
  */
-void blt_mem_init(int fd, struct blt_mem_data *mem)
+void blt_mem_copy_init(int fd, struct blt_mem_copy_data *mem,
+		       enum blt_memop_mode mode,
+		       enum blt_memop_type copy_type)
 {
 	memset(mem, 0, sizeof(*mem));
 
 	mem->fd = fd;
 	mem->driver = get_intel_driver(fd);
+	mem->mode = mode;
+	mem->copy_type = copy_type;
 }
 
-static void emit_blt_mem_copy(int fd, uint64_t ahnd, const struct blt_mem_data *mem)
+static void dump_bb_mem_copy_cmd(struct xe_mem_copy_data *data)
 {
-	uint64_t dst_offset, src_offset;
-	int i;
-	uint32_t *batch;
-	uint32_t optype;
+	uint32_t *cmd = (uint32_t *) data;
+
+	igt_info("BB details:\n");
+	igt_info(" dw00: [%08x] <client: 0x%x, opcode: 0x%x, length: %d> "
+		 "[copy type: %d, mode: %d]\n",
+		 cmd[0], data->dw00.client, data->dw00.opcode, data->dw00.length,
+		 data->dw00.copy_type, data->dw00.mode);
+	igt_info(" dw01: [%08x] width: %u\n", cmd[1],
+		 data->dw00.mode == MODE_BYTE ? data->dw01.byte_copy.width :
+						data->dw01.page_copy.width);
+	igt_info(" dw02: [%08x] height: %u\n", cmd[2], data->dw02.height);
+	igt_info(" dw03: [%08x] src pitch: %u\n", cmd[3], data->dw03.src_pitch);
+	igt_info(" dw04: [%08x] dst pitch: %u\n", cmd[4], data->dw04.dst_pitch);
+	igt_info(" dw05: [%08x] src offset lo (0x%x)\n",
+		 cmd[5], data->dw05.src_address_lo);
+	igt_info(" dw06: [%08x] src offset hi (0x%x)\n",
+		 cmd[6], data->dw06.src_address_hi);
+	igt_info(" dw07: [%08x] dst offset lo (0x%x)\n",
+		 cmd[7], data->dw07.dst_address_lo);
+	igt_info(" dw08: [%08x] dst offset hi (0x%x)\n",
+		 cmd[8], data->dw08.dst_address_hi);
+	igt_info(" dw09: [%08x] mocs <dst: 0x%x, src: 0x%x>\n",
+		 cmd[8], data->dw09.dst_mocs, data->dw09.src_mocs);
+}
+
+static uint64_t emit_blt_mem_copy(int fd, uint64_t ahnd,
+				  const struct blt_mem_copy_data *mem,
+				  uint64_t bb_pos, bool emit_bbe)
+{
+	struct xe_mem_copy_data data = {};
+	uint64_t dst_offset, src_offset, shift;
+	uint32_t width, height, width_max, height_max, remain;
+	uint32_t bbe = MI_BATCH_BUFFER_END;
+	uint32_t *bb;
+
+	if (mem->mode == MODE_BYTE) {
+		data.dw01.byte_copy.width = -1;
+		height_max = width_max = data.dw01.byte_copy.width + 1;
+		shift = width_max;
+	} else {
+		data.dw01.page_copy.width = -1;
+		width_max = data.dw01.page_copy.width + 1;
+		height_max = 1;
+		shift = width_max << 8;
+	}
 
 	src_offset = get_offset_pat_index(ahnd, mem->src.handle, mem->src.size,
 					  0, mem->src.pat_index);
 	dst_offset = get_offset_pat_index(ahnd, mem->dst.handle, mem->dst.size,
 					  0, mem->dst.pat_index);
 
-	batch = bo_map(fd, mem->bb.handle, mem->bb.size, mem->driver);
-	optype = mem->src.type == M_MATRIX ? 1 << 17 : 0;
+	bb = bo_map(fd, mem->bb.handle, mem->bb.size, mem->driver);
 
-	i = 0;
-	batch[i++] = MEM_COPY_CMD | optype;
-	batch[i++] = mem->src.width - 1;
-	batch[i++] = mem->src.height - 1;
-	batch[i++] = mem->src.pitch - 1;
-	batch[i++] = mem->dst.pitch - 1;
-	batch[i++] = src_offset;
-	batch[i++] = src_offset << 32;
-	batch[i++] = dst_offset;
-	batch[i++] = dst_offset << 32;
-	batch[i++] = mem->src.mocs_index << MEM_COPY_MOCS_SHIFT | mem->dst.mocs_index;
-	batch[i++] = MI_BATCH_BUFFER_END;
+	width = mem->src.width;
+	height = mem->dst.height;
 
-	munmap(batch, mem->bb.size);
+	data.dw00.client = 0x2;
+	data.dw00.opcode = 0x5a;
+	data.dw00.length = 8;
+	data.dw00.mode = mem->mode;
+	data.dw00.copy_type = mem->copy_type;
+
+	data.dw02.height = height - 1;
+	data.dw05.src_address_lo = src_offset;
+	data.dw06.src_address_hi = src_offset >> 32;
+	data.dw07.dst_address_lo = dst_offset;
+	data.dw08.dst_address_hi = dst_offset >> 32;
+	data.dw09.src_mocs = mem->src.mocs_index;
+	data.dw09.dst_mocs = mem->dst.mocs_index;
+
+	/* For matrix we don't iterate */
+	if (mem->copy_type == TYPE_MATRIX) {
+		if (width > width_max) {
+			width = width_max;
+			igt_warn("src width is bigger than max width [%u > %u => %u], truncating it\n",
+				 mem->src.width, width_max, width);
+		}
+
+		if (height > height_max) {
+			height = height_max;
+			igt_warn("src height is bigger than max height [%u > %u => %u], truncating it\n",
+				 mem->src.height, height_max, height);
+		}
+
+		data.dw01.byte_copy.width = width - 1;
+		data.dw03.src_pitch = mem->src.pitch - 1;
+		data.dw04.dst_pitch = mem->dst.pitch - 1;
+
+		igt_assert(bb_pos + sizeof(data) < mem->bb.size);
+		memcpy(bb + bb_pos, &data, sizeof(data));
+		bb_pos += sizeof(data);
+
+		if (mem->print_bb) {
+			igt_info("[MEM COPY]\n");
+			dump_bb_mem_copy_cmd(&data);
+		}
+	} else {
+		remain = mem->src.width;
+
+		/* Truncate pitches to match operation bits */
+		if (mem->src.pitch > width_max)
+			data.dw03.src_pitch = width_max - 1;
+		else
+			data.dw03.src_pitch = mem->src.pitch;
+
+		if (mem->dst.pitch > width_max)
+			data.dw04.dst_pitch = width_max - 1;
+		else
+			data.dw04.dst_pitch = mem->dst.pitch;
+
+		while (remain) {
+			data.dw01.val = min_t(uint32_t, width_max, remain) - 1;
+
+			igt_assert(bb_pos + sizeof(data) < mem->bb.size);
+			memcpy(bb + bb_pos, &data, sizeof(data));
+			bb_pos += sizeof(data);
+
+			remain -= remain > width_max ? width_max : remain;
+			src_offset += shift;
+			dst_offset += shift;
+
+			data.dw05.src_address_lo = src_offset;
+			data.dw06.src_address_hi = src_offset >> 32;
+			data.dw07.dst_address_lo = dst_offset;
+			data.dw08.dst_address_hi = dst_offset >> 32;
+
+			if (mem->print_bb) {
+				igt_info("[MEM COPY]\n");
+				dump_bb_mem_copy_cmd(&data);
+			}
+		}
+	}
+
+	if (emit_bbe) {
+		igt_assert(bb_pos + sizeof(uint32_t) < mem->bb.size);
+		memcpy(bb + bb_pos, &bbe, sizeof(bbe));
+		bb_pos += sizeof(uint32_t);
+	}
+
+	munmap(bb, mem->bb.size);
+
+	return bb_pos;
 }
 
+
 /**
  * blt_mem_copy:
  * @fd: drm fd
@@ -1811,7 +2050,7 @@ static void emit_blt_mem_copy(int fd, uint64_t ahnd, const struct blt_mem_data *
 int blt_mem_copy(int fd, const intel_ctx_t *ctx,
 		 const struct intel_execution_engine2 *e,
 		 uint64_t ahnd,
-		 const struct blt_mem_data *mem)
+		 const struct blt_mem_copy_data *mem)
 {
 	struct drm_i915_gem_execbuffer2 execbuf = {};
 	struct drm_i915_gem_exec_object2 obj[3] = {};
@@ -1824,7 +2063,7 @@ int blt_mem_copy(int fd, const intel_ctx_t *ctx,
 					  0, mem->dst.pat_index);
 	bb_offset = get_offset(ahnd, mem->bb.handle, mem->bb.size, 0);
 
-	emit_blt_mem_copy(fd, ahnd, mem);
+	emit_blt_mem_copy(fd, ahnd, mem, 0, true);
 
 	if (mem->driver == INTEL_DRIVER_XE) {
 		intel_ctx_xe_exec(ctx, ahnd, CANONICAL(bb_offset));
@@ -1852,7 +2091,26 @@ int blt_mem_copy(int fd, const intel_ctx_t *ctx,
 	return ret;
 }
 
-static void emit_blt_mem_set(int fd, uint64_t ahnd, const struct blt_mem_data *mem,
+/**
+ * blt_mem_set_init:
+ * @fd: drm fd
+ * @mem: structure for initialization
+ *
+ * Function is zeroing @mem and sets fd and driver fields (INTEL_DRIVER_I915 or
+ * INTEL_DRIVER_XE).
+ */
+void blt_mem_set_init(int fd, struct blt_mem_set_data *mem,
+		      enum blt_memop_type fill_type)
+{
+	memset(mem, 0, sizeof(*mem));
+
+	mem->fd = fd;
+	mem->driver = get_intel_driver(fd);
+	mem->fill_type = fill_type;
+}
+
+static void emit_blt_mem_set(int fd, uint64_t ahnd,
+			     const struct blt_mem_set_data *mem,
 			     uint8_t fill_data)
 {
 	uint64_t dst_offset;
@@ -1895,7 +2153,7 @@ static void emit_blt_mem_set(int fd, uint64_t ahnd, const struct blt_mem_data *m
 int blt_mem_set(int fd, const intel_ctx_t *ctx,
 		const struct intel_execution_engine2 *e,
 		uint64_t ahnd,
-		const struct blt_mem_data *mem,
+		const struct blt_mem_set_data *mem,
 		uint8_t fill_data)
 {
 	struct drm_i915_gem_execbuffer2 execbuf = {};
@@ -1987,7 +2245,7 @@ blt_create_object(const struct blt_copy_data *blt, uint32_t region,
 		if (create_mapping && region != system_memory(blt->fd))
 			flags |= DRM_XE_GEM_CREATE_FLAG_NEEDS_VISIBLE_VRAM;
 
-		if (AT_LEAST_GEN(intel_get_drm_devid(blt->fd), 20) && compression) {
+		if (intel_gen(intel_get_drm_devid(blt->fd)) >= 20 && compression) {
 			pat_index = intel_get_pat_idx_uc_comp(blt->fd);
 			cpu_caching = DRM_XE_GEM_CPU_CACHING_WC;
 		}
@@ -2051,14 +2309,13 @@ void blt_set_mem_object(struct blt_mem_object *obj,
 			uint32_t handle, uint64_t size, uint32_t pitch,
 			uint32_t width, uint32_t height, uint32_t region,
 			uint8_t mocs_index, uint8_t pat_index,
-			enum blt_memop_type type, enum blt_compression compression)
+			enum blt_compression compression)
 {
 	obj->handle = handle;
 	obj->region = region;
 	obj->size = size;
 	obj->mocs_index = mocs_index;
 	obj->pat_index = pat_index;
-	obj->type = type;
 	obj->compression = compression;
 	obj->width = width;
 	obj->height = height;
@@ -2214,7 +2471,7 @@ void blt_surface_get_flatccs_data(int fd,
 		cpu_caching = __xe_default_cpu_caching(fd, sysmem, 0);
 		ccs_bo_size = ALIGN(ccssize, xe_get_default_alignment(fd));
 
-		if (AT_LEAST_GEN(intel_get_drm_devid(fd), 20) && obj->compression) {
+		if (intel_gen(intel_get_drm_devid(fd)) >= 20 && obj->compression) {
 			comp_pat_index  = intel_get_pat_idx_uc_comp(fd);
 			cpu_caching = DRM_XE_GEM_CPU_CACHING_WC;
 		}
