@@ -7,6 +7,7 @@
  */
 
 #include <string.h>
+#include <sys/timerfd.h>
 
 #include "drmtest.h"
 #include "igt.h"
@@ -125,6 +126,47 @@ void xe_spin_init(struct xe_spin *spin, struct xe_spin_opts *opts)
 		spin->batch[b++] = ticks_delta_addr >> 32;
 	}
 
+	if (opts->mem_copy) {
+		uint32_t src_width, src_pitch, dst_width, dst_pitch;
+
+		src_width = opts->mem_copy->src->width;
+		src_pitch = opts->mem_copy->src->pitch;
+		dst_width = opts->mem_copy->dst->width;
+		dst_pitch = opts->mem_copy->dst->pitch;
+
+		if (src_width > dst_width) {
+			igt_warn("src width must be <= dst width\n");
+			src_width = dst_width;
+		}
+
+		if (src_width > SZ_256K) {
+			igt_warn("src width must be less than 256K, limiting it\n");
+			src_width = SZ_256K;
+		}
+
+		if (src_pitch > SZ_256K) {
+			igt_warn("src pitch must be less than 256K, limiting it\n");
+			src_pitch = SZ_256K;
+		}
+
+		if (dst_pitch > SZ_256K) {
+			igt_warn("dst pitch must be less than 256K, limiting it\n");
+			dst_pitch = SZ_256K;
+		}
+
+		spin->batch[b++] = MEM_COPY_CMD;
+		spin->batch[b++] = src_width - 1;
+		spin->batch[b++] = 1;  /* for byte copying this is ignored */
+		spin->batch[b++] = src_pitch - 1;
+		spin->batch[b++] = dst_pitch - 1;
+		spin->batch[b++] = opts->mem_copy->src_offset;
+		spin->batch[b++] = opts->mem_copy->src_offset << 32;
+		spin->batch[b++] = opts->mem_copy->dst_offset;
+		spin->batch[b++] = opts->mem_copy->dst_offset << 32;
+		spin->batch[b++] = opts->mem_copy->src->mocs_index << XE2_MEM_COPY_MOCS_SHIFT |
+				   opts->mem_copy->dst->mocs_index;
+	}
+
 	spin->batch[b++] = MI_COND_BATCH_BUFFER_END | MI_DO_COMPARE | 2;
 	spin->batch[b++] = 0;
 	spin->batch[b++] = end_addr;
@@ -145,7 +187,7 @@ void xe_spin_init(struct xe_spin *spin, struct xe_spin_opts *opts)
  */
 bool xe_spin_started(struct xe_spin *spin)
 {
-	return spin->start != 0;
+	return READ_ONCE(spin->start) != 0;
 }
 
 /**
@@ -162,7 +204,7 @@ void xe_spin_wait_started(struct xe_spin *spin)
 
 void xe_spin_end(struct xe_spin *spin)
 {
-	spin->end = 0;
+	WRITE_ONCE(spin->end, 0);
 }
 
 /**
@@ -250,7 +292,16 @@ void xe_spin_free(int fd, struct igt_spin *spin)
 	igt_assert(spin->driver == INTEL_DRIVER_XE);
 
 	if (spin->timerfd >= 0) {
+#ifdef ANDROID
+		struct itimerspec its;
+
+		memset(&its, 0, sizeof(its));
+		its.it_value.tv_sec = 0;
+		its.it_value.tv_nsec = 1;
+		timerfd_settime(spin->timerfd, 0, &its, NULL);
+#else
 		pthread_cancel(spin->timer_thread);
+#endif
 		igt_assert(pthread_join(spin->timer_thread, NULL) == 0);
 		close(spin->timerfd);
 	}
