@@ -1,7 +1,11 @@
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
+#ifdef ANDROID
+#include "android/glib.h"
+#else
 #include <glib.h>
+#endif
 #ifdef __linux__
 #include <linux/watchdog.h>
 #endif
@@ -47,6 +51,12 @@ static struct {
 	size_t num_dogs;
 } watchdogs;
 
+static void runner_gettime(struct timespec *tv)
+{
+	if (clock_gettime(CLOCK_BOOTTIME, tv))
+		clock_gettime(CLOCK_REALTIME, tv);
+}
+
 __attribute__((format(printf, 2, 3)))
 static void __logf__(FILE *stream, const char *fmt, ...)
 {
@@ -54,8 +64,7 @@ static void __logf__(FILE *stream, const char *fmt, ...)
 	struct timespec tv;
 	va_list ap;
 
-	if (clock_gettime(CLOCK_BOOTTIME, &tv))
-		clock_gettime(CLOCK_REALTIME, &tv);
+	runner_gettime(&tv);
 	fprintf(stream, "[%ld.%06ld] ", tv.tv_sec, tv.tv_nsec / 1000);
 
 	va_start(ap, fmt);
@@ -610,6 +619,16 @@ void close_outputs(int *fds)
 	}
 }
 
+static void fsync_outputs(int *fds)
+{
+	int i;
+
+	for (i = 0; i < _F_LAST; i++) {
+		if (fds[i] >= 0)
+			fsync(fds[i]);
+	}
+}
+
 const char *get_out_filename(int fid)
 {
 	if (fid >= 0 && fid < _F_LAST)
@@ -961,7 +980,7 @@ static int monitor_output(pid_t child,
 	bool socket_comms_used = false; /* whether the test actually uses comms */
 	bool results_received = false; /* whether we already have test results that might need overriding if we detect an abort condition */
 
-	igt_gettime(&time_beg);
+	runner_gettime(&time_beg);
 	time_last_activity = time_last_subtest = time_killed = time_beg;
 
 	if (errfd > nfds)
@@ -1024,7 +1043,7 @@ static int monitor_output(pid_t child,
 			return -1;
 		}
 
-		igt_gettime(&time_now);
+		runner_gettime(&time_now);
 
 		/* TODO: Refactor these handlers to their own functions */
 		if (outfd >= 0 && FD_ISSET(outfd, &set)) {
@@ -1567,7 +1586,7 @@ static int monitor_output(pid_t child,
 		if (settings->disk_usage_limit && disk_usage > settings->disk_usage_limit) {
 			char disk[1024];
 
-			snprintf(disk, sizeof(disk), "igt_runner: disk limit exceeded at dmesg dump, %ld > %ld\n", disk_usage, settings->disk_usage_limit);
+			snprintf(disk, sizeof(disk), "igt_runner: disk limit exceeded at dmesg dump, %zu > %zu\n", disk_usage, settings->disk_usage_limit);
 			if (settings->log_level >= LOG_LEVEL_NORMAL) {
 				outf("%s", disk);
 				fflush(stdout);
@@ -1866,14 +1885,19 @@ static int execute_next_entry(struct execute_state *state,
 out_kmsgfd:
 	close(kmsgfd);
 out_pipe:
-	close_outputs(outputs);
 	close(outpipe[0]);
 	close(outpipe[1]);
 	close(errpipe[0]);
 	close(errpipe[1]);
+	if (settings->sync)
+		fsync_outputs(outputs);
 	close_outputs(outputs);
 out_dirfd:
+	if (settings->sync)
+		fsync(dirfd);
 	close(dirfd);
+	if (settings->sync)
+		fsync(resdirfd);
 
 	return result;
 }
