@@ -27,7 +27,8 @@
 static void
 test_compute_square(int fd)
 {
-	igt_require_f(run_intel_compute_kernel(fd, NULL), "GPU not supported\n");
+	igt_require_f(run_intel_compute_kernel(fd, NULL, EXECENV_PREF_SYSTEM),
+		      "GPU not supported\n");
 }
 
 igt_main
