@@ -33,166 +33,80 @@
 /**
  * TEST: gem ctx param
  * Description: Basic test for context set/get param input validation.
- * Run type: FULL
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: uapi
+ * Functionality: get/set IOCTLs
+ * Feature: context
+ * Test category: GEM_Legacy
  *
  * SUBTEST: basic
- * Category: Infrastructure
  * Description: Basic test for context get/set param ioctls using valid context
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: basic-default
- * Category: Infrastructure
  * Description: Basic test for context get/set param ioctls using default context
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: get-priority-new-ctx
- * Category: Infrastructure
- * Description:
- *   Test performed with context param set to priority.
- *   Verify that priority is default for newly created context
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Test performed with context param set to priority. Verify that
+ *		priority is default for newly created context
  *
  * SUBTEST: invalid-ctx-get
- * Category: Infrastructure
- * Description: Verify that context get param ioctl using invalid context returns relevant error
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Verify that context get param ioctl using invalid context
+ *		returns relevant error
  *
  * SUBTEST: invalid-ctx-set
- * Category: Infrastructure
- * Description: Verify that context set param ioctl using invalid context returns relevant error
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Verify that context set param ioctl using invalid context
+ *		returns relevant error
  *
  * SUBTEST: invalid-get-engines
- * Category: Infrastructure
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: invalid-get-no-zeromap
- * Category: Infrastructure
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: invalid-get-ringsize
- * Category: Infrastructure
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: invalid-param-get
- * Category: Infrastructure
- * Description: Checks that fetching context parameters using an unused param value is erroneous
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Checks that fetching context parameters using an unused param
+ *		value is erroneous
  *
  * SUBTEST: invalid-param-set
- * Category: Infrastructure
- * Description: Checks that setting context parameters using an unused param value is erroneous
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Checks that setting context parameters using an unused param
+ *		value is erroneous
  *
  * SUBTEST: invalid-set-no-zeromap
- * Category: Infrastructure
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: invalid-set-ringsize
- * Category: Infrastructure
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: invalid-size-get
- * Category: Infrastructure
- * Description: Verify that context get param ioctl returns valid size for valid context
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Verify that context get param ioctl returns valid size for
+ *		valid context
  *
  * SUBTEST: invalid-size-set
- * Category: Infrastructure
- * Description: Verify that context set param ioctl using invalid size returns relevant error
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Verify that context set param ioctl using invalid size returns
+ *		relevant error
  *
  * SUBTEST: non-root-set
- * Category: Infrastructure
- * Description: Verify that context set param ioctl returns relevant error in non root mode
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Verify that context set param ioctl returns relevant error in
+ *		non root mode
  *
  * SUBTEST: root-set
- * Category: Infrastructure
  * Description: Verify that context set param ioctl works fine in root mode
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: set-priority-invalid-size
- * Category: Infrastructure
- * Description:
- *   Test performed with context param set to priority.
- *   Verify that relevant error is returned on setting invalid ctx size with default priority
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Test performed with context param set to priority. Verify that
+ *		relevant error is returned on setting invalid ctx size with
+ *		default priority
  *
  * SUBTEST: set-priority-not-supported
- * Description:
- *   Verify that context set param ioctl returns relevant error if driver doesn't supports
- *   assigning custom priorities from userspace
- * Feature: context, no-set-priority
+ * Description: Verify that context set param ioctl returns relevant error if
+ *		driver doesn't supports assigning custom priorities from
+ *		userspace
  *
  * SUBTEST: set-priority-range
- * Category: Infrastructure
- * Description:
- *   Test performed with context param set to priority.
- *   Change priority range to test value overflow
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Test performed with context param set to priority. Change
+ *		priority range to test value overflow
  *
  * SUBTEST: vm
- * Category: Infrastructure
  * Description: Tests that multiple contexts can share the same VMA
- * Feature: context
- * Functionality: context management
- * Sub-category: i915
- * Test category: GEM_Legacy
  */
 
 IGT_TEST_DESCRIPTION("Basic test for context set/get param input validation.");
