@@ -47,189 +47,81 @@
 #include "sw_sync.h"
 /**
  * TEST: gem ctx persistence
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: CMD submission
+ * Functionality: context
  * Feature: context
- * Run type: FULL
+ * Test category: GEM_Legacy
  *
  * SUBTEST: engines-cleanup
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-hang
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-hostile
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-hostile-preempt
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-mixed
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-mixed-process
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-persistence
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: engines-queued
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: file
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: hang
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: heartbeat-close
  *
  * SUBTEST: heartbeat-hang
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: heartbeat-hostile
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: heartbeat-many
  *
  * SUBTEST: heartbeat-stop
  *
  * SUBTEST: hostile
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: idempotent
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-cleanup
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-hang
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-hostile
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-hostile-preempt
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-mixed
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-mixed-process
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-persistence
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: legacy-engines-queued
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: many-contexts
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: process
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: processes
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: saturated-hostile
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: saturated-hostile-nopreempt
  *
  * SUBTEST: smoketest
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
  *
  * SUBTEST: userptr
- * Category: Server
- * Functionality: security
- * Sub-category: Compute
- * Test category: GEM_Legacy
+ *
  */
 
 #define RESET_TIMEOUT_MS 2 * MSEC_PER_SEC; /* default: 640ms */
 static unsigned long reset_timeout_ms = RESET_TIMEOUT_MS;
-#define NSEC_PER_MSEC (1000 * 1000ull)
 
 static void cleanup(int i915)
 {
@@ -1137,6 +1029,9 @@ test_saturated_hostile_all(int i915, const intel_ctx_t *base_ctx,
 	igt_spin_busywait_until_started(spin);
 	intel_ctx_destroy(i915, ctx);
 
+	/* Give the kernel some time to terminate the context */
+	usleep(reset_timeout_ms * 1000);
+
 	/* Hostile request requires a GPU reset to terminate */
 	igt_assert_eq(wait_for_status(spin->out_fence, reset_timeout_ms), -EIO);
 
@@ -1200,10 +1095,12 @@ static void test_processes(int i915)
 
 			/* Wait until we are told to die */
 			pid = getpid();
-			write(p[i].sv[0], &pid, sizeof(pid));
+			igt_assert_eq(write(p[i].sv[0], &pid, sizeof(pid)),
+				      sizeof(pid));
 
 			pid = 0;
-			read(p[i].sv[0], &pid, sizeof(pid));
+			igt_assert_eq(read(p[i].sv[0], &pid, sizeof(pid)),
+				      sizeof(pid));
 			igt_assert(pid == getpid());
 		}
 	}
@@ -1216,8 +1113,10 @@ static void test_processes(int i915)
 		igt_assert_eq(sync_fence_wait(fence, 0), -ETIME);
 
 		/* Kill *this* process */
-		read(p[i].sv[1], &pid, sizeof(pid));
-		write(p[i].sv[1], &pid, sizeof(pid));
+		igt_assert_eq(read(p[i].sv[1], &pid, sizeof(pid)),
+			      sizeof(pid));
+		igt_assert_eq(write(p[i].sv[1], &pid, sizeof(pid)),
+			      sizeof(pid));
 
 		/*
 		 * A little bit of slack required for the signal to terminate
@@ -1277,6 +1176,9 @@ static void __smoker(int i915, const intel_ctx_cfg_t *cfg,
 	drm_close_driver(fd);
 	flush_delayed_fput(i915);
 
+	/* Give the kernel some time to terminate the context */
+	usleep(reset_timeout_ms * 1000);
+
 	igt_spin_end(spin);
 
 	igt_assert_eq(wait_for_status(spin->out_fence, timeout), expected);
