@@ -47,58 +47,34 @@
 /**
  * TEST: i915 pm rps
  * Description: Render P-States tests - verify GPU frequency changes
+ * Category: Core
+ * Mega feature: Power management
+ * Sub-category: Power management tests
+ * Functionality: pm_rps
+ * Feature: pm_rps
+ * Test category: pm_rps
  *
  * SUBTEST: basic-api
- * Feature: pm_rps
- * Run type: BAT
  *
  * SUBTEST: engine-order
  * Description:
  *   Check if context reuse does not affect waitboosting.
  *   Render P-States tests - verify GPU frequency changes
- * Feature: pm_rps
- * Run type: FULL
- * Test category: pm_rps
  *
  * SUBTEST: fence-order
  * Description:
  *   Check if the order of fences does not affect waitboosting.
  *   Render P-States tests - verify GPU frequency changes
- * Feature: pm_rps, synchronization
- * Run type: FULL
- * Test category: pm_rps
+ * Feature: pm_rps, synchronization feature
  *
  * SUBTEST: min-max-config-idle
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: min-max-config-loaded
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: reset
- * Feature: pm_rps
- * Run type: FULL
- *
- * SUBTEST: waitboost
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: thresholds
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: thresholds-idle
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: thresholds-idle-park
- * Feature: pm_rps
- * Run type: FULL
- *
  * SUBTEST: thresholds-park
- * Feature: pm_rps
- * Run type: FULL
+ * SUBTEST: waitboost
  */
 
 IGT_TEST_DESCRIPTION("Render P-States tests - verify GPU frequency changes");
@@ -346,7 +322,8 @@ static void load_helper_run(enum load load)
 			spin[high_load] = __igt_spin_new(drm_fd, .ahnd = ahnd);
 
 			if (lh.signal && high_load != prev_load) {
-				write(lh.link, &lh.signal, sizeof(lh.signal));
+				igt_assert_eq(write(lh.link, &lh.signal, sizeof(lh.signal)),
+					      sizeof(lh.signal));
 				lh.signal = false;
 			}
 			prev_load = high_load;
@@ -678,7 +655,7 @@ static void waitboost(int fd, bool reset)
 static uint32_t batch_create(int i915, uint64_t sz)
 {
 	const uint32_t bbe = MI_BATCH_BUFFER_END;
-	const uint32_t chk = 0x5 << 23;
+	const uint32_t chk = MI_ARB_CHECK;
 	uint32_t handle = gem_create(i915, sz);
 	uint32_t *map;
 
@@ -714,9 +691,9 @@ static uint64_t __fence_order(int i915,
 	obj->flags = flags1;
 	gem_execbuf(i915, eb);
 
-	read(fd, before, sizeof(before));
+	igt_assert_eq(read(fd, before, sizeof(before)), sizeof(before));
 	gem_sync(i915, obj->handle);
-	read(fd, after, sizeof(after));
+	igt_assert_eq(read(fd, after, sizeof(after)), sizeof(after));
 	close(fd);
 
 	after[0] -= before[0];
@@ -820,9 +797,9 @@ static uint64_t __engine_order(int i915,
 		gem_execbuf(i915, eb);
 	}
 
-	read(fd, before, sizeof(before));
+	igt_assert_eq(read(fd, before, sizeof(before)), sizeof(before));
 	gem_sync(i915, obj->handle);
-	read(fd, after, sizeof(after));
+	igt_assert_eq(read(fd, after, sizeof(after)), sizeof(after));
 	close(fd);
 
 	after[0] -= before[0];
@@ -1185,7 +1162,8 @@ igt_main
 
 	igt_subtest_with_dynamic("thresholds-idle") {
 		int tmp, gt;
-
+		igt_skip_on_f(i915_is_slpc_enabled(drm_fd),
+			      "This subtest is not supported when SLPC is enabled\n");
 		i915_for_each_gt(drm_fd, tmp, gt) {
 			igt_dynamic_f("gt%u", gt)
 				test_thresholds(drm_fd, gt, TEST_IDLE);
@@ -1194,7 +1172,8 @@ igt_main
 
 	igt_subtest_with_dynamic("thresholds") {
 		int tmp, gt;
-
+		igt_skip_on_f(i915_is_slpc_enabled(drm_fd),
+			      "This subtest is not supported when SLPC is enabled\n");
 		i915_for_each_gt(drm_fd, tmp, gt) {
 			igt_dynamic_f("gt%u", gt)
 				test_thresholds(drm_fd, gt, 0);
@@ -1203,7 +1182,8 @@ igt_main
 
 	igt_subtest_with_dynamic("thresholds-park") {
 		int tmp, gt;
-
+		igt_skip_on_f(i915_is_slpc_enabled(drm_fd),
+			      "This subtest is not supported when SLPC is enabled\n");
 		i915_for_each_gt(drm_fd, tmp, gt) {
 			igt_dynamic_f("gt%u", gt)
 				test_thresholds(drm_fd, gt, TEST_PARK);
@@ -1212,6 +1192,8 @@ igt_main
 
 	igt_subtest_with_dynamic("thresholds-idle-park") {
 		int tmp, gt;
+		igt_skip_on_f(i915_is_slpc_enabled(drm_fd),
+			      "This subtest is not supported when SLPC is enabled\n");
 
 		i915_for_each_gt(drm_fd, tmp, gt) {
 			igt_dynamic_f("gt%u", gt)
