@@ -26,121 +26,68 @@
  * TEST: kms flip scaled crc
  * Category: Display
  * Description: Test flipping between scaled/nonscaled framebuffers
+ * Driver requirement: i915, xe
+ * Mega feature: General Display Features
  */
+
 #include "igt.h"
 
 /**
  * SUBTEST: flip-64bpp-ytile-to-32bpp-ytilegen12rcccs-upscaling
  * Description: Flip from 64bpp non scaled fb to 32bpp upscaled fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-ytile-to-32bpp-ytilercccs-downscaling
  * Description: Flip from 64bpp non scaled fb to 32bpp downscaled fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-linear-to-64bpp-linear-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-4tile-to-32bpp-4tiledg2rcccs-%s
  * Description: Flip from 32bpp non scaled fb to 32bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-4tile-to-64bpp-4tile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-xtile-to-64bpp-xtile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-yftile-to-32bpp-yftileccs-%s
  * Description: Flip from 32bpp non scaled fb to 32bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-yftile-to-64bpp-yftile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-yftileccs-to-64bpp-yftile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-ytile-to-32bpp-ytileccs-%s
  * Description: Flip from 32bpp non scaled fb to 32bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-ytile-to-32bpp-ytilegen12rcccs-%s
  * Description: Flip from 32bpp non scaled fb to 32bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-ytile-to-64bpp-ytile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-32bpp-ytileccs-to-64bpp-ytile-%s
  * Description: Flip from 32bpp non scaled fb to 64bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-4tile-to-32bpp-4tiledg2rcccs-%s
  * Description: Flip from 64bpp non scaled fb to 32bpp %arg[1] fb to stress CD
  *              clock programming
- * Driver requirement: i915, xe
- * Functionality: ccs, scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * arg[1]:
  *
@@ -152,42 +99,22 @@
  * SUBTEST: flip-64bpp-4tile-to-%dbpp-4tile-%s
  * Description: Flip from 64bpp non scaled fb to %arg[1]bpp %arg[2] fb to stress
  *              CD clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-xtile-to-%dbpp-xtile-%s
  * Description: Flip from 64bpp non scaled fb to %arg[1]bpp %arg[2] fb to stress
  *              CD clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-yftile-to-%dbpp-yftile-%s
  * Description: Flip from 64bpp non scaled fb to %arg[1]bpp %arg[2] fb to stress
  *              CD clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-ytile-to-%dbpp-ytile-%s
  * Description: Flip from 64bpp non scaled fb to %arg[1]bpp %arg[2] fb to stress
  *              CD clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * SUBTEST: flip-64bpp-linear-to-%dbpp-linear-%s
  * Description: Flip from 64bpp non scaled fb to %arg[1]bpp %arg[2] fb to stress
  *              CD clock programming
- * Driver requirement: i915, xe
- * Functionality: scaling, tiling, vblank
- * Mega feature: General Display Features
- * Test category: functionality test
  *
  * arg[1].values: 16, 32
  * arg[2]:
@@ -826,7 +753,7 @@ igt_main
 					igt_output_set_pipe(output, pipe);
 					igt_output_override_mode(output, modetoset);
 
-					if (modetoset && i915_pipe_output_combo_valid(&data.display)) {
+					if (modetoset && intel_pipe_output_combo_valid(&data.display)) {
 						found = true;
 						igt_dynamic_f("pipe-%s-valid-mode", kmstest_pipe_name(pipe))
 							run_tests(&data, index, pipe, output, modetoset);
@@ -838,7 +765,7 @@ igt_main
 						igt_display_reset(&data.display);
 
 						igt_output_set_pipe(output, pipe);
-						if (!i915_pipe_output_combo_valid(&data.display))
+						if (!intel_pipe_output_combo_valid(&data.display))
 							continue;
 
 						modetoset = NULL;
