@@ -490,6 +490,10 @@ test_aperture_limit(uint32_t region, uint64_t size)
 	uint64_t size1 = (gem_mappable_aperture_size(fd) * 7) / 8;
 	uint64_t size2 = (gem_mappable_aperture_size(fd) * 3) / 8;
 
+	igt_require(gem_has_mappable_ggtt(fd));
+	igt_require(size1 >= size2);
+	igt_require(size2 >= size);
+
 	handle1 = gem_create(fd, size1);
 	dma_buf_fd1 = prime_handle_to_fd_for_mmap(fd, handle1);
 	igt_assert(errno == 0);
@@ -498,7 +502,7 @@ test_aperture_limit(uint32_t region, uint64_t size)
 	fill_bo_cpu(ptr1, size);
 	igt_assert(memcmp(ptr1, pattern, sizeof(pattern)) == 0);
 
-	handle2 = gem_create(fd, size1);
+	handle2 = gem_create(fd, size2);
 	dma_buf_fd2 = prime_handle_to_fd_for_mmap(fd, handle2);
 	igt_assert(errno == 0);
 	ptr2 = mmap(NULL, size2, PROT_READ | PROT_WRITE, MAP_SHARED, dma_buf_fd2, 0);
