@@ -48,6 +48,9 @@
  * SUBTEST: utilization-single-full-load
  * Description: Check that each engine shows full load
  *
+ * SUBTEST: utilization-single-full-load-while-active
+ * Description: Check that each engine shows full load whle active
+ *
  * SUBTEST: utilization-single-full-load-isolation
  * Description: Check that each engine load does not spill over to other drm clients
  *
@@ -69,8 +72,8 @@ IGT_TEST_DESCRIPTION("Read and verify drm client memory consumption and engine u
 #define BO_SIZE (65536)
 
 /* flag masks */
-#define TEST_BUSY		(1 << 0)
-#define TEST_TRAILING_IDLE	(1 << 1)
+#define TEST_WITH_LOAD		(1 << 0)
+#define TEST_WHILE_ACTIVE	(1 << 1)
 #define TEST_ISOLATION		(1 << 2)
 #define TEST_VIRTUAL		(1 << 3)
 #define TEST_PARALLEL		(1 << 4)
@@ -423,6 +426,12 @@ check_results(struct pceu_cycles *s1, struct pceu_cycles *s2,
 	}
 }
 
+static void end_cork(int fd, struct xe_cork *cork)
+{
+	if (cork && !cork->ended)
+		xe_cork_sync_end(fd, cork);
+}
+
 static void
 utilization_single(int fd, struct drm_xe_engine_class_instance *hwe, unsigned int flags)
 {
@@ -439,7 +448,7 @@ utilization_single(int fd, struct drm_xe_engine_class_instance *hwe, unsigned in
 		new_fd = drm_reopen_driver(fd);
 
 	vm = xe_vm_create(fd, 0, 0);
-	if (flags & TEST_BUSY) {
+	if (flags & TEST_WITH_LOAD) {
 		cork = xe_cork_create_opts(fd, hwe, vm, 1, 1);
 		xe_cork_sync_start(fd, cork);
 	}
@@ -449,14 +458,16 @@ utilization_single(int fd, struct drm_xe_engine_class_instance *hwe, unsigned in
 		read_engine_cycles(new_fd, pceu1[1]);
 
 	usleep(batch_duration_usec);
-	if (flags & TEST_TRAILING_IDLE)
-		xe_cork_sync_end(fd, cork);
+	if (!(flags & TEST_WHILE_ACTIVE))
+		end_cork(fd, cork);
 
 	read_engine_cycles(fd, pceu2[0]);
 	if (flags & TEST_ISOLATION)
 		read_engine_cycles(new_fd, pceu2[1]);
 
-	expected_load = flags & TEST_BUSY ?
+	end_cork(fd, cork);
+
+	expected_load = flags & TEST_WITH_LOAD ?
 	       EXPECTED_LOAD_FULL : EXPECTED_LOAD_IDLE;
 
 	check_results(pceu1[0], pceu2[0], hwe->engine_class, 1,
@@ -497,7 +508,7 @@ utilization_single_destroy_queue(int fd, struct drm_xe_engine_class_instance *hw
 	usleep(batch_duration_usec);
 
 	/* destroy queue before sampling again */
-	xe_cork_sync_end(fd, cork);
+	end_cork(fd, cork);
 	timestamp = cork->spin->timestamp;
 	xe_cork_destroy(fd, cork);
 
@@ -526,7 +537,7 @@ utilization_others_idle(int fd, struct drm_xe_engine_class_instance *hwe)
 
 	read_engine_cycles(fd, pceu1);
 	usleep(batch_duration_usec);
-	xe_cork_sync_end(fd, cork);
+	end_cork(fd, cork);
 	read_engine_cycles(fd, pceu2);
 
 	xe_for_each_engine_class(class) {
@@ -568,10 +579,8 @@ utilization_others_full_load(int fd, struct drm_xe_engine_class_instance *hwe)
 
 	read_engine_cycles(fd, pceu1);
 	usleep(batch_duration_usec);
-	xe_for_each_engine_class(class) {
-		if (cork[class])
-			xe_cork_sync_end(fd, cork[class]);
-	}
+	xe_for_each_engine_class(class)
+		end_cork(fd, cork[class]);
 
 	read_engine_cycles(fd, pceu2);
 
@@ -613,10 +622,8 @@ utilization_all_full_load(int fd)
 
 	read_engine_cycles(fd, pceu1);
 	usleep(batch_duration_usec);
-	xe_for_each_engine_class(class) {
-		if (cork[class])
-			xe_cork_sync_end(fd, cork[class]);
-	}
+	xe_for_each_engine_class(class)
+		end_cork(fd, cork[class]);
 
 	read_engine_cycles(fd, pceu2);
 
@@ -681,7 +688,7 @@ utilization_multi(int fd, int gt, int class, unsigned int flags)
 		fd_spill = drm_reopen_driver(fd);
 
 	vm = xe_vm_create(fd, 0, 0);
-	if (flags & TEST_BUSY) {
+	if (flags & TEST_WITH_LOAD) {
 		cork = xe_cork_create_opts(fd, eci, vm, width, num_placements);
 		xe_cork_sync_start(fd, cork);
 	}
@@ -691,14 +698,14 @@ utilization_multi(int fd, int gt, int class, unsigned int flags)
 		read_engine_cycles(fd_spill, pceu_spill[0]);
 
 	usleep(batch_duration_usec);
-	if (flags & TEST_TRAILING_IDLE)
-		xe_cork_sync_end(fd, cork);
+	if (!(flags & TEST_WHILE_ACTIVE))
+		end_cork(fd, cork);
 
 	read_engine_cycles(fd, pceu[1]);
 	if (flags & TEST_ISOLATION)
 		read_engine_cycles(fd_spill, pceu_spill[1]);
 
-	expected_load = flags & TEST_BUSY ?
+	expected_load = flags & TEST_WITH_LOAD ?
 	       EXPECTED_LOAD_FULL : EXPECTED_LOAD_IDLE;
 
 	check_results(pceu[0], pceu[1], class, width,
@@ -769,16 +776,23 @@ igt_main
 			utilization_single(xe, hwe, 0);
 	}
 
+	igt_subtest("utilization-single-full-load-while-active") {
+		require_engine_utilization_data(xe);
+		xe_for_each_engine(xe, hwe)
+			utilization_single(xe, hwe,
+					   TEST_WITH_LOAD | TEST_WHILE_ACTIVE);
+	}
+
 	igt_subtest("utilization-single-full-load") {
 		require_engine_utilization_data(xe);
 		xe_for_each_engine(xe, hwe)
-			utilization_single(xe, hwe, TEST_BUSY | TEST_TRAILING_IDLE);
+			utilization_single(xe, hwe, TEST_WITH_LOAD);
 	}
 
 	igt_subtest("utilization-single-full-load-isolation") {
 		require_engine_utilization_data(xe);
 		xe_for_each_engine(xe, hwe)
-			utilization_single(xe, hwe, TEST_BUSY | TEST_TRAILING_IDLE | TEST_ISOLATION);
+			utilization_single(xe, hwe, TEST_WITH_LOAD | TEST_ISOLATION);
 	}
 
 	igt_subtest("utilization-single-full-load-destroy-queue") {
@@ -819,8 +833,7 @@ igt_main
 				xe_for_each_engine_class(class)
 					utilization_multi(xe, gt, class,
 							  s->flags |
-							  TEST_BUSY |
-							  TEST_TRAILING_IDLE);
+							  TEST_WITH_LOAD);
 		}
 
 		igt_subtest_f("%s-utilization-single-full-load-isolation",
@@ -830,8 +843,7 @@ igt_main
 				xe_for_each_engine_class(class)
 					utilization_multi(xe, gt, class,
 							  s->flags |
-							  TEST_BUSY |
-							  TEST_TRAILING_IDLE |
+							  TEST_WITH_LOAD |
 							  TEST_ISOLATION);
 		}
 	}
