@@ -14,16 +14,32 @@
  * SUBTEST: non-blocking-read
  * Description: Verify non-blocking read of EU stall data during a workload run
  *
+ * SUBTEST: non-blocking-re-enable
+ * Description: Run non-blocking read test twice with disable and enable between the runs
+ *
  * SUBTEST: blocking-read
  * Description: Verify blocking read of EU stall data during a workload run
  *
+ * SUBTEST: blocking-re-enable
+ * Description: Run blocking read test twice with disable and enable between the runs
+ *
  * SUBTEST: unprivileged-access
  * Description: Verify unprivileged open of a EU stall data stream fd
+ *
+ * SUBTEST: invalid-gt-id
+ * Description: Verify that invalid input GT ID fails the test
+ *
+ * SUBTEST: invalid-sampling-rate
+ * Description: Verify that invalid input sampling rate fails the test
+ *
+ * SUBTEST: invalid-event-report-count
+ * Description: Verify that invalid input event report count fails the test
  */
 
 #include <fcntl.h>
 #include <poll.h>
 #include <sys/ioctl.h>
+#include <sys/stat.h>
 #include <sys/wait.h>
 
 #include "igt.h"
@@ -33,6 +49,9 @@
 
 #define OBSERVATION_PARANOID	"/proc/sys/dev/xe/observation_paranoid"
 
+#define NUM_DATA_ROWS(size)	((size) >> 6)
+
+#define MAX_XECORES		64
 #define NUM_ITERS_GPGPU_FILL	100
 #define DEFAULT_NUM_REPORTS	1
 #define DEFAULT_SAMPLE_RATE	(251 * 4)
@@ -46,13 +65,17 @@
 static FILE *output;
 static char *p_args[8];
 static char *output_file;
+static uint8_t *user_buf;
 static uint8_t p_gt_id;
 static uint32_t p_rate;
 static uint32_t p_user = DEFAULT_USER_BUF_SIZE;
 static uint32_t p_num_reports = DEFAULT_NUM_REPORTS;
+static int stream_fd = -1;
 
 static volatile bool child_is_running = true;
 
+static struct drm_xe_query_eu_stall *query_eu_stall_data;
+
 /*
  * EU stall data format for PVC
  */
@@ -283,6 +306,60 @@ static void set_fd_flags(int fd, int flags)
 	igt_assert_eq(0, fcntl(fd, F_SETFL, old | flags));
 }
 
+static void eu_stall_close(int fd)
+{
+	close(fd);
+	stream_fd = -1;
+}
+
+static int eu_stall_open(int drm_fd, struct xe_eu_stall_open_prop *props)
+{
+	int ret;
+
+	if (stream_fd >= 0)
+		eu_stall_close(stream_fd);
+
+	ret = xe_eu_stall_ioctl(drm_fd, DRM_XE_OBSERVATION_OP_STREAM_OPEN, props);
+	igt_assert_fd(ret);
+
+	return ret;
+}
+
+/*
+ * Verify that tests with invalid arguments fail.
+ */
+static void test_invalid_arguments(int drm_fd, uint8_t gt_id, uint32_t rate, uint32_t num_reports)
+{
+	uint64_t properties[] = {
+		DRM_XE_EU_STALL_PROP_GT_ID, gt_id,
+		DRM_XE_EU_STALL_PROP_SAMPLE_RATE, rate,
+		DRM_XE_EU_STALL_PROP_WAIT_NUM_REPORTS, num_reports,
+	};
+
+	struct xe_eu_stall_open_prop props = {
+		.num_properties = ARRAY_SIZE(properties) / 2,
+		.properties_ptr = to_user_pointer(properties),
+	};
+
+	xe_eu_stall_ioctl_err(drm_fd, DRM_XE_OBSERVATION_OP_STREAM_OPEN, &props, EINVAL);
+}
+
+static void test_invalid_gt_id(int fd)
+{
+	test_invalid_arguments(fd, 255, DEFAULT_SAMPLE_RATE, DEFAULT_NUM_REPORTS);
+}
+
+static void test_invalid_sampling_rate(int fd)
+{
+	test_invalid_arguments(fd, 0, 251 * 10, DEFAULT_NUM_REPORTS);
+}
+
+static void test_invalid_event_report_count(int fd)
+{
+	test_invalid_arguments(fd, 0, DEFAULT_SAMPLE_RATE,
+			       NUM_DATA_ROWS(512 * 1024) * MAX_XECORES + 1);
+}
+
 static inline void enable_paranoid(void)
 {
 	write_u64_file(OBSERVATION_PARANOID, 1);
@@ -299,7 +376,11 @@ static inline void disable_paranoid(void)
  */
 static void test_non_privileged_access(int drm_fd)
 {
-	int paranoid, stream_fd;
+	int paranoid;
+
+	/* Close any open stream fd before fork() */
+	if (stream_fd >= 0)
+		eu_stall_close(stream_fd);
 
 	paranoid = read_u64_file(OBSERVATION_PARANOID);
 
@@ -341,9 +422,8 @@ static void test_non_privileged_access(int drm_fd)
 
 		igt_drop_root();
 
-		stream_fd = xe_eu_stall_ioctl(drm_fd, DRM_XE_OBSERVATION_OP_STREAM_OPEN, &props);
-		igt_require_fd(stream_fd);
-		close(stream_fd);
+		stream_fd = eu_stall_open(drm_fd, &props);
+		eu_stall_close(stream_fd);
 	}
 
 	igt_waitchildren();
@@ -413,14 +493,13 @@ static void print_eu_stall_data(uint32_t devid, uint8_t *buf, size_t size)
  * while the parent process reads the stall counters data, disables EU stall
  * counters once the workload completes execution.
  */
-static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
+static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read, int iter)
 {
-	uint32_t num_samples = 0, num_drops = 0;
+	uint32_t num_samples, num_drops;
 	struct igt_helper_process work_load = {};
 	struct sigaction sa = { 0 };
-	int ret, flags, stream_fd;
-	uint64_t total_size = 0;
-	uint8_t *buf;
+	int ret, flags;
+	uint64_t total_size;
 
 	uint64_t properties[] = {
 		DRM_XE_EU_STALL_PROP_GT_ID, p_gt_id,
@@ -433,39 +512,15 @@ static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
 		.properties_ptr = to_user_pointer(properties),
 	};
 
-	struct drm_xe_query_eu_stall *query_eu_stall_data;
-	struct drm_xe_device_query query = {
-		.extensions = 0,
-		.query = DRM_XE_DEVICE_QUERY_EU_STALL,
-		.size = 0,
-		.data = 0,
-	};
-
 	igt_info("User buffer size: %u\n", p_user);
 	if (p_args[0])
 		igt_info("Workload: %s\n", p_args[0]);
 	else
 		igt_info("Workload: GPGPU fill\n");
 
-	buf = malloc(p_user);
-	igt_assert(buf);
+	igt_info("Sampling Rate: %u\n", p_rate);
 
-	igt_assert_eq(igt_ioctl(drm_fd, DRM_IOCTL_XE_DEVICE_QUERY, &query), 0);
-	igt_assert_neq(query.size, 0);
-
-	query_eu_stall_data = malloc(query.size);
-	igt_assert(query_eu_stall_data);
-
-	query.data = to_user_pointer(query_eu_stall_data);
-	igt_assert_eq(igt_ioctl(drm_fd, DRM_IOCTL_XE_DEVICE_QUERY, &query), 0);
-
-	igt_assert(query_eu_stall_data->num_sampling_rates > 0);
-	if (p_rate == 0)
-		properties[3] = query_eu_stall_data->sampling_rates[0];
-	igt_info("Sampling Rate: %lu\n", properties[3]);
-
-	stream_fd = xe_eu_stall_ioctl(drm_fd, DRM_XE_OBSERVATION_OP_STREAM_OPEN, &props);
-	igt_require_fd(stream_fd);
+	stream_fd = eu_stall_open(drm_fd, &props);
 
 	if (!blocking_read)
 		flags = O_CLOEXEC | O_NONBLOCK;
@@ -473,7 +528,7 @@ static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
 		flags = O_CLOEXEC;
 
 	set_fd_flags(stream_fd, flags);
-
+enable:
 	do_ioctl(stream_fd, DRM_XE_OBSERVATION_IOCTL_ENABLE, 0);
 
 	sa.sa_handler = sighandler;
@@ -493,6 +548,9 @@ static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
 			_exit(run_gpgpu_fill(drm_fd, devid));
 		}
 	}
+	total_size = 0;
+	num_samples = 0;
+	num_drops = 0;
 	/* Parent process reads the EU stall counters data */
 	do {
 		if (!blocking_read) {
@@ -504,11 +562,11 @@ static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
 			igt_assert_eq(ret, 1);
 			igt_assert(pollfd.revents & POLLIN);
 		}
-		ret = read(stream_fd, buf, p_user);
+		ret = read(stream_fd, user_buf, p_user);
 		if (ret > 0) {
 			total_size += ret;
 			if (output)
-				print_eu_stall_data(devid, buf, ret);
+				print_eu_stall_data(devid, user_buf, ret);
 			num_samples += ret / query_eu_stall_data->record_size;
 		} else if ((ret < 0) && (errno != EAGAIN)) {
 			if (errno == EINTR)
@@ -523,18 +581,21 @@ static void test_eustall(int drm_fd, uint32_t devid, bool blocking_read)
 		}
 	} while (child_is_running);
 
-	igt_info("Total size read: %lu\n", total_size);
+	do_ioctl(stream_fd, DRM_XE_OBSERVATION_IOCTL_DISABLE, 0);
+
+	igt_info("Total size read: %" PRIu64 "\n", total_size);
 	igt_info("Number of samples: %u\n", num_samples);
 	igt_info("Number of drops reported: %u\n", num_drops);
 
-	do_ioctl(stream_fd, DRM_XE_OBSERVATION_IOCTL_DISABLE, 0);
-
-	close(stream_fd);
-	free(buf);
-
 	ret = wait_child(&work_load);
 	igt_assert_f(ret == 0, "waitpid() - ret: %d, errno: %d\n", ret, errno);
-	igt_assert_f(num_samples, "No EU stalls detected during the workload\n");
+	if (!igt_run_in_simulation())
+		igt_assert_f(num_samples, "No EU stalls detected during the workload\n");
+
+	if (--iter)
+		goto enable;
+
+	eu_stall_close(stream_fd);
 }
 
 static int opt_handler(int opt, int opt_index, void *data)
@@ -585,37 +646,88 @@ static struct option long_options[] = {
 
 igt_main_args("e:g:o:r:u:w:", long_options, help_str, opt_handler, NULL)
 {
-	int drm_fd;
-	uint32_t devid;
 	bool blocking_read = true;
+	int drm_fd, ret;
+	uint32_t devid;
+	struct stat sb;
+	struct drm_xe_device_query query = {
+		.extensions = 0,
+		.query = DRM_XE_DEVICE_QUERY_EU_STALL,
+		.size = 0,
+		.data = 0,
+	};
 
 	igt_fixture {
 		drm_fd = drm_open_driver(DRIVER_XE);
 		igt_require_fd(drm_fd);
 		devid = intel_get_drm_devid(drm_fd);
-		igt_require(IS_PONTEVECCHIO(devid) || intel_graphics_ver(devid) >= IP_VER(20, 0));
+
 		igt_require_f(igt_get_gpgpu_fillfunc(devid), "no gpgpu-fill function\n");
+		igt_require_f(!stat(OBSERVATION_PARANOID, &sb), "no observation_paranoid file\n");
+
+		ret = igt_ioctl(drm_fd, DRM_IOCTL_XE_DEVICE_QUERY, &query);
+		igt_skip_on_f(ret == -1 && errno == ENODEV,
+			      "EU stall monitoring is not available on this platform\n");
+		igt_skip_on_f(ret == -1 && errno == EINVAL,
+			      "EU stall monitoring is not supported in the driver\n");
+		igt_assert_neq(query.size, 0);
+
+		query_eu_stall_data = malloc(query.size);
+		igt_assert(query_eu_stall_data);
+
+		query.data = to_user_pointer(query_eu_stall_data);
+		igt_assert_eq(igt_ioctl(drm_fd, DRM_IOCTL_XE_DEVICE_QUERY, &query), 0);
+
+		igt_assert(query_eu_stall_data->num_sampling_rates > 0);
+		if (p_rate == 0)
+			p_rate = query_eu_stall_data->sampling_rates[0];
+
 		if (output_file) {
 			output = fopen(output_file, "w");
 			igt_require(output);
 		}
+		user_buf = malloc(p_user);
+		igt_assert(user_buf);
 	}
 
 	igt_describe("Verify non-blocking read of EU stall data during a workload run");
 	igt_subtest("non-blocking-read") {
-		test_eustall(drm_fd, devid, !blocking_read);
+		test_eustall(drm_fd, devid, !blocking_read, 1);
+	}
+
+	igt_describe("Run non-blocking read test twice with disable and enable between the runs");
+	igt_subtest("non-blocking-re-enable") {
+		test_eustall(drm_fd, devid, !blocking_read, 2);
 	}
 
 	igt_describe("Verify blocking read of EU stall data during a workload run");
 	igt_subtest("blocking-read") {
-		test_eustall(drm_fd, devid, blocking_read);
+		test_eustall(drm_fd, devid, blocking_read, 1);
+	}
+
+	igt_describe("Run blocking read test twice with disable and enable between the runs");
+	igt_subtest("blocking-re-enable") {
+		test_eustall(drm_fd, devid, blocking_read, 2);
 	}
 
 	igt_describe("Verify that unprivileged open of a EU stall data fd fails");
 	igt_subtest("unprivileged-access")
 		test_non_privileged_access(drm_fd);
 
+	igt_describe("Verify that invalid input GT ID fails the test");
+	igt_subtest("invalid-gt-id")
+		test_invalid_gt_id(drm_fd);
+
+	igt_describe("Verify that invalid input sampling rate fails the test");
+	igt_subtest("invalid-sampling-rate")
+		test_invalid_sampling_rate(drm_fd);
+
+	igt_describe("Verify that invalid input event report count fails the test");
+	igt_subtest("invalid-event-report-count")
+		test_invalid_event_report_count(drm_fd);
+
 	igt_fixture {
+		free(user_buf);
 		if (output)
 			fclose(output);
 		drm_close_driver(drm_fd);
