@@ -7,7 +7,7 @@
  * TEST: Test EU Debugger functionality
  * Category: Core
  * Mega feature: EUdebug
- * Sub-category: EUdebug tests
+ * Sub-category: EUdebug framework
  * Functionality: eu debugger framework
  * Test category: functionality test
  */
@@ -28,6 +28,7 @@
 
 /**
  * SUBTEST: sysfs-toggle
+ * Functionality: enable
  * Description:
  *	Exercise the debugger enable/disable sysfs toggle logic
  */
@@ -64,6 +65,7 @@ static void test_sysfs_toggle(int fd)
 #define VM_BIND_DELAY_UFENCE_ACK	(1 << 8)
 #define VM_BIND_UFENCE_RECONNECT	(1 << 9)
 #define VM_BIND_UFENCE_SIGINT_CLIENT	(1 << 10)
+#define TEST_FAULTABLE			(1 << 30)
 #define TEST_DISCOVERY			(1 << 31)
 
 #define PAGE_SIZE SZ_4K
@@ -542,6 +544,7 @@ static int __debug_connect(int fd, int *debugfd, struct drm_xe_eudebug_connect *
 
 /**
  * SUBTEST: basic-connect
+ * Functionality: attach
  * Description:
  *	Exercise XE_EUDEBUG_CONNECT ioctl with passing
  *	valid and invalid params.
@@ -622,6 +625,7 @@ static void switch_user(__uid_t uid, __gid_t gid)
 
 /**
  * SUBTEST: connect-user
+ * Functionality: attach
  * Description:
  *	Verify unprivileged XE_EUDEBUG_CONNECT ioctl.
  *	Check:
@@ -758,6 +762,7 @@ static void test_connect_user(int fd)
 
 /**
  * SUBTEST: basic-close
+ * Functionality: attach
  * Description:
  *	Test whether eudebug can be reattached after closure.
  */
@@ -786,6 +791,7 @@ static void test_close(int fd)
 
 /**
  * SUBTEST: basic-read-event
+ * Functionality: events
  * Description:
  *	Synchronously exercise eu debugger event polling and reading.
  */
@@ -881,50 +887,59 @@ static void test_read_event(int fd)
 
 /**
  * SUBTEST: basic-client
+ * Functionality: attach
  * Description:
  *	Attach the debugger to process which opens and closes xe drm client.
  *
  * SUBTEST: basic-client-th
+ * Functionality: attach
  * Description:
  *	Create client basic resources (vms) in multiple threads
  *
  * SUBTEST: multiple-sessions
+ * Functionality: multisessions
  * Description:
  *	Simultaneously attach many debuggers to many processes.
  *	Each process opens and closes xe drm client and creates few resources.
  *
- * SUBTEST: basic-%s
+ * SUBTEST: basic-exec-queues
+ * Functionality: exec queues events
  * Description:
- *	Attach the debugger to process which creates and destroys a few %arg[1].
+ *	Attach the debugger to process which creates and destroys a few exec-queues.
+ *
+ * SUBTEST: basic-vms
+ * Functionality: VM events
+ * Description:
+ *	Attach the debugger to process which creates and destroys a few vms.
  *
  * SUBTEST: basic-vm-bind
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs synchronous vm bind
  *	and vm unbind.
  *
  * SUBTEST: basic-vm-bind-vm-destroy
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs vm bind, and destroys
  *	the vm without unbinding. Make sure that we don't get unbind events.
  *
  * SUBTEST: basic-vm-bind-extended
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs bind, bind array, rebind,
  *	partial unbind, unbind and unbind all operations.
  *
  * SUBTEST: multigpu-basic-client
+ * Functionality: attach multiGPU
  * Description:
  *	Attach the debugger to process which opens and closes xe drm client on all Xe devices.
  *
  * SUBTEST: multigpu-basic-client-many
+ * Functionality: attach multiGPU
  * Description:
  *	Simultaneously attach many debuggers to many processes on all Xe devices.
  *	Each process opens and closes xe drm client and creates few resources.
- *
- * arg[1]:
- *
- * @vms: vms
- * @exec-queues: exec queues
  */
 
 static void test_basic_sessions(int fd, unsigned int flags, int count, bool match_opposite)
@@ -951,22 +966,26 @@ static void test_basic_sessions(int fd, unsigned int flags, int count, bool matc
 
 /**
  * SUBTEST: basic-vm-bind-discovery
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs vm-bind before attaching
  *	and check if the discovery process reports it.
  *
  * SUBTEST: basic-vm-bind-metadata-discovery
+ * Functionality: VM bind metadata
  * Description:
  *	Attach the debugger to a process that performs vm-bind with metadata attached
  *	before attaching and check if the discovery process reports it.
  *
  * SUBTEST: basic-vm-bind-vm-destroy-discovery
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs vm bind, and destroys
  *	the vm without unbinding before attaching. Make sure that we don't get
  *	any bind/unbind and vm create/destroy events.
  *
  * SUBTEST: basic-vm-bind-extended-discovery
+ * Functionality: VM bind event
  * Description:
  *	Attach the debugger to a process that performs bind, bind array, rebind,
  *	partial unbind, and unbind all operations before attaching. Ensure that
@@ -1077,6 +1096,7 @@ static void run_discovery_client(struct xe_eudebug_client *c)
 
 /**
  * SUBTEST: discovery-%s
+ * Functionality: event discovery
  * Description: Race discovery against %arg[1] and the debugger dettach.
  *
  * arg[1]:
@@ -1136,7 +1156,7 @@ static void *discovery_race_thread(void *data)
 
 			xe_eudebug_debugger_stop_worker(s->debugger, 1);
 
-			igt_debug("Resources discovered: %lu\n", s->debugger->event_count);
+			igt_debug("Resources discovered: %" PRIu64 "\n", s->debugger->event_count);
 			if (!s->client->done) {
 				xe_eudebug_for_each_event(e, s->debugger->log) {
 					if (e->type == DRM_XE_EUDEBUG_EVENT_OPEN) {
@@ -1445,6 +1465,7 @@ static void test_basic_sessions_th(int fd, unsigned int flags, int num_clients,
 static void vm_access_client(struct xe_eudebug_client *c)
 {
 	struct drm_xe_engine_class_instance *hwe = c->ptr;
+	uint32_t vm_flags = DRM_XE_VM_CREATE_FLAG_LR_MODE;
 	uint32_t bo_placement;
 	struct bind_list *bl;
 	uint32_t vm;
@@ -1454,7 +1475,8 @@ static void vm_access_client(struct xe_eudebug_client *c)
 
 	fd = xe_eudebug_client_open_driver(c);
 
-	vm = xe_eudebug_client_vm_create(c, fd, DRM_XE_VM_CREATE_FLAG_LR_MODE, 0);
+	vm_flags |= (c->flags & TEST_FAULTABLE) ? DRM_XE_VM_CREATE_FLAG_FAULT_MODE : 0;
+	vm = xe_eudebug_client_vm_create(c, fd, vm_flags, 0);
 
 	if (c->flags & VM_BIND_OP_MAP_USERPTR)
 		bo_placement = 0;
@@ -1562,22 +1584,36 @@ static void vm_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: basic-vm-access
+ * Functionality: VM access
  * Description:
  *      Exercise XE_EUDEBUG_VM_OPEN with pread and pwrite into the
  *      vm fd, concerning many different offsets inside the vm,
  *      and many virtual addresses of the vm_bound object.
  *
+ * SUBTEST: basic-vm-access-faultable
+ * Functionality: VM access with FAULTABLE_VM
+ * Description:
+ *      Fault variation of test basic-vm-access.
+ *
  * SUBTEST: basic-vm-access-userptr
+ * Functionality: VM access
  * Description:
  *      Exercise XE_EUDEBUG_VM_OPEN with pread and pwrite into the
  *      vm fd, concerning many different offsets inside the vm,
  *      and many virtual addresses of the vm_bound object, but backed
  *      by userptr.
+ *
+ * SUBTEST: basic-vm-access-userptr-faultable
+ * Functionality: VM access with FAULTABLE_VM
+ * Description:
+ *      Fault variation of test basic-vm-access-userptr.
  */
 static void test_vm_access(int fd, unsigned int flags, int num_clients)
 {
 	struct drm_xe_engine_class_instance *hwe;
 
+	igt_require(!(flags & TEST_FAULTABLE) || !xe_supports_faults(fd));
+
 	xe_eudebug_for_each_engine(fd, hwe)
 		test_client_with_trigger(fd, flags, num_clients,
 					 vm_access_client,
@@ -1713,19 +1749,33 @@ static void vm_trigger_access_parameters(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: basic-vm-access-parameters
+ * Functionality: VM access
  * Description:
  *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage
  *      with bo backing storage.
  *
+ * SUBTEST: basic-vm-access-parameters-faultable
+ * Functionality: VM access with FAULTABLE_VM
+ * Description:
+ *	Fault variation of test basic-vm-access-parameters.
+ *
  * SUBTEST: basic-vm-access-parameters-userptr
+ * Functionality: VM access
  * Description:
  *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage
  *      with userptr backing storage.
+ *
+ * SUBTEST: basic-vm-access-parameters-userptr-faultable
+ * Functionality: VM access with FAULTABLE_VM
+ * Description:
+ *      Fault variation of test basic-vm-access-parameters-userptr.
  */
 static void test_vm_access_parameters(int fd, unsigned int flags, int num_clients)
 {
 	struct drm_xe_engine_class_instance *hwe;
 
+	igt_require(!(flags & TEST_FAULTABLE) || !xe_supports_faults(fd));
+
 	xe_eudebug_for_each_engine(fd, hwe)
 		test_client_with_trigger(fd, flags, num_clients,
 					 vm_access_client,
@@ -1845,6 +1895,7 @@ static void metadata_read_on_vm_bind_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: read-metadata
+ * Functionality: metadata
  * Description:
  *      Exercise DRM_XE_EUDEBUG_IOCTL_READ_METADATA and debug metadata create|destroy events.
  */
@@ -1857,6 +1908,7 @@ static void test_metadata_read(int fd, unsigned int flags, int num_clients)
 
 /**
  * SUBTEST: attach-debug-metadata
+ * Functionality: metadata
  * Description:
  *      Read debug metadata when vm_bind has it attached.
  */
@@ -2073,19 +2125,23 @@ static int wait_for_ufence_events(struct ufence_priv *priv, int timeout_ms)
 
 /**
  * SUBTEST: basic-vm-bind-ufence
+ * Functionality: VM bind event
  * Description:
  *      Give user fence in application and check if ufence ack works
  *
  * SUBTEST: basic-vm-bind-ufence-delay-ack
+ * Functionality: VM bind event
  * Description:
  *	Give user fence in application and check if delayed ufence ack works
  *
  * SUBTEST: basic-vm-bind-ufence-reconnect
+ * Functionality: VM bind event
  * Description:
  *	Give user fence in application, hold it, drop the debugger connection and check if anything
  *	breaks. Expect that held acks are released when connection is dropped.
  *
  * SUBTEST: basic-vm-bind-ufence-sigint-client
+ * Functionality: SIGINT
  * Description:
  *	Give user fence in application, hold it, send SIGINT to client and check if anything breaks.
  */
@@ -2185,10 +2241,14 @@ static void *vm_bind_clear_thread(void *data)
 	struct vm_bind_clear_thread_priv *priv = data;
 	int fd = xe_eudebug_client_open_driver(priv->c);
 	uint32_t gtt_size = 1ull << min_t(uint32_t, xe_va_bits(fd), 48);
-	uint32_t vm = xe_eudebug_client_vm_create(priv->c, fd, DRM_XE_VM_CREATE_FLAG_LR_MODE, 0);
+	uint32_t vm_flags = DRM_XE_VM_CREATE_FLAG_LR_MODE;
 	size_t bo_size = xe_bb_size(fd, batch_size);
 	unsigned long count = 0;
 	uint64_t *fence_data;
+	uint32_t vm;
+
+	vm_flags |= (priv->c->flags & TEST_FAULTABLE) ? DRM_XE_VM_CREATE_FLAG_FAULT_MODE : 0;
+	vm = xe_eudebug_client_vm_create(priv->c, fd, vm_flags, 0);
 
 	/* init uf_sync */
 	fence_data = aligned_alloc(xe_get_default_alignment(fd), sizeof(*fence_data));
@@ -2395,16 +2455,24 @@ static void vm_bind_clear_ack_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: vm-bind-clear
+ * Functionality: memory access
  * Description:
  *      Check that fresh buffers we vm_bind into the ppGTT are always clear.
+ *
+ * SUBTEST: vm-bind-clear-faultable
+ * Functionality: memory access with FAULTABLE_VM
+ * Description:
+ *      Fault variation of test vm-bind-clear.
  */
-static void test_vm_bind_clear(int fd)
+static void test_vm_bind_clear(int fd, uint32_t flags)
 {
 	struct vm_bind_clear_priv *priv;
 	struct xe_eudebug_session *s;
 
+	igt_require(!(flags & TEST_FAULTABLE) || !xe_supports_faults(fd));
+
 	priv = vm_bind_clear_priv_create();
-	s = xe_eudebug_session_create(fd, vm_bind_clear_client, 0, priv);
+	s = xe_eudebug_session_create(fd, vm_bind_clear_client, flags, priv);
 
 	xe_eudebug_debugger_add_trigger(s->debugger, DRM_XE_EUDEBUG_EVENT_VM_BIND_OP,
 					vm_bind_clear_test_trigger);
@@ -2433,11 +2501,15 @@ static void vma_ufence_client(struct xe_eudebug_client *c)
 	const unsigned int n = UFENCE_EVENT_COUNT_EXPECTED;
 	int fd = xe_eudebug_client_open_driver(c);
 	struct ufence_bind *binds = create_binds_with_ufence(fd, n);
-	uint32_t vm = xe_eudebug_client_vm_create(c, fd, DRM_XE_VM_CREATE_FLAG_LR_MODE, 0);
+	uint32_t vm_flags = DRM_XE_VM_CREATE_FLAG_LR_MODE;
 	size_t bo_size = xe_get_default_alignment(fd);
 	uint64_t items = bo_size / sizeof(uint32_t);
 	uint32_t bo[UFENCE_EVENT_COUNT_EXPECTED];
 	uint32_t *ptr[UFENCE_EVENT_COUNT_EXPECTED];
+	uint32_t vm;
+
+	vm_flags |= (c->flags & TEST_FAULTABLE) ? DRM_XE_VM_CREATE_FLAG_FAULT_MODE : 0;
+	vm = xe_eudebug_client_vm_create(c, fd, vm_flags, 0);
 
 	for (int i = 0; i < n; i++) {
 		bo[i] = xe_bo_create(fd, 0, bo_size,
@@ -2597,7 +2669,7 @@ static void vma_ufence_trigger(struct xe_eudebug_debugger *d,
 				    ef->vm_bind_ref_seqno);
 		xe_eudebug_assert_f(d, eb->flags & DRM_XE_EUDEBUG_EVENT_VM_BIND_FLAG_UFENCE,
 				    "vm bind event does not have ufence: %s\n", event_str);
-		igt_debug("vm bind ufence event received with ref %lld, addr 0x%lx, range 0x%lx\n",
+		igt_debug("vm bind ufence event received with ref %lld, addr 0x%" PRIu64 ", range 0x%" PRIu64 "\n",
 			  ef->vm_bind_ref_seqno,
 			  addr,
 			  range);
@@ -2610,15 +2682,23 @@ static void vma_ufence_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: vma-ufence
+ * Functionality: check ufence blocking
  * Description:
  *      Intercept vm bind after receiving ufence event, then access target vm and write to it.
  *      Then check on client side if the write was successful.
+ *
+ * SUBTEST: vma-ufence-faultable
+ * Functionality: check ufence blocking with FAULTABLE_VM
+ * Description:
+ *      Fault variation of test vma-ufence.
  */
 static void test_vma_ufence(int fd, unsigned int flags)
 {
 	struct xe_eudebug_session *s;
 	struct ufence_priv *priv;
 
+	igt_require(!(flags & TEST_FAULTABLE) || !xe_supports_faults(fd));
+
 	priv = ufence_priv_create();
 	s = xe_eudebug_session_create(fd, vma_ufence_client, flags, priv);
 
@@ -2647,6 +2727,7 @@ static void test_vma_ufence(int fd, unsigned int flags)
 
 /**
  * SUBTEST: basic-exec-queues-enable
+ * Functionality: exec queues events
  * Description:
  *      Test the exec queue property of enabling eudebug
  */
@@ -2742,17 +2823,31 @@ igt_main
 	igt_subtest("basic-client-th")
 		test_basic_sessions_th(fd, 0, 1, true);
 
-	igt_subtest("basic-vm-access")
-		test_vm_access(fd, 0, 1);
 
-	igt_subtest("basic-vm-access-userptr")
-		test_vm_access(fd, VM_BIND_OP_MAP_USERPTR, 1);
+	igt_subtest_group {
+		uint32_t flags[] = {0, TEST_FAULTABLE};
+		const char *suffix[] = {"", "-faultable"};
 
-	igt_subtest("basic-vm-access-parameters")
-		test_vm_access_parameters(fd, 0, 1);
+		for (int i = 0; i < ARRAY_SIZE(flags); i++) {
+			igt_subtest_f("basic-vm-access%s", suffix[i])
+				test_vm_access(fd, flags[i], 1);
 
-	igt_subtest("basic-vm-access-parameters-userptr")
-		test_vm_access_parameters(fd, VM_BIND_OP_MAP_USERPTR, 1);
+			igt_subtest_f("basic-vm-access-userptr%s", suffix[i])
+				test_vm_access(fd, VM_BIND_OP_MAP_USERPTR | flags[i], 1);
+
+			igt_subtest_f("basic-vm-access-parameters%s", suffix[i])
+				test_vm_access_parameters(fd, flags[i], 1);
+
+			igt_subtest_f("basic-vm-access-parameters-userptr%s", suffix[i])
+				test_vm_access_parameters(fd, VM_BIND_OP_MAP_USERPTR | flags[i], 1);
+
+			igt_subtest_f("vma-ufence%s", suffix[i])
+				test_vma_ufence(fd, flags[i]);
+
+			igt_subtest_f("vm-bind-clear%s", suffix[i])
+				test_vm_bind_clear(fd, flags[i]);
+		}
+	}
 
 	igt_subtest("multiple-sessions")
 		test_basic_sessions(fd, CREATE_VMS | CREATE_EXEC_QUEUES, 4, true);
@@ -2781,12 +2876,6 @@ igt_main
 	igt_subtest("basic-vm-bind-ufence-sigint-client")
 		test_basic_ufence(fd, VM_BIND_UFENCE_SIGINT_CLIENT);
 
-	igt_subtest("vma-ufence")
-		test_vma_ufence(fd, 0);
-
-	igt_subtest("vm-bind-clear")
-		test_vm_bind_clear(fd);
-
 	igt_subtest("basic-vm-bind-discovery")
 		test_basic_discovery(fd, VM_BIND, true);
 
@@ -2834,7 +2923,6 @@ igt_main
 	igt_subtest_group {
 		igt_fixture {
 			gpu_count = drm_prepare_filtered_multigpu(DRIVER_XE);
-			igt_require(gpu_count >= 2);
 
 			multigpu_was_enabled = malloc(gpu_count * sizeof(bool));
 			igt_assert(multigpu_was_enabled);
@@ -2846,6 +2934,7 @@ igt_main
 		}
 
 		igt_subtest("multigpu-basic-client") {
+			igt_require(gpu_count >= 2);
 			igt_multi_fork(child, gpu_count) {
 				fd = drm_open_filtered_card(child);
 				igt_assert_f(fd > 0, "cannot open gpu-%d, errno=%d\n",
@@ -2859,6 +2948,7 @@ igt_main
 		}
 
 		igt_subtest("multigpu-basic-client-many") {
+			igt_require(gpu_count >= 2);
 			igt_multi_fork(child, gpu_count) {
 				fd = drm_open_filtered_card(child);
 				igt_assert_f(fd > 0, "cannot open gpu-%d, errno=%d\n",
