@@ -146,6 +146,9 @@ static void vram_d3cold_threshold_restore(int sig)
 
 static bool setup_d3(device_t device, enum igt_acpi_d_state state)
 {
+	igt_require_f(igt_has_pci_pm_capability(device.pci_xe),
+		      "PCI power management capability not found\n");
+
 	dpms_on_off(device, DRM_MODE_DPMS_OFF);
 
 	/*
@@ -740,7 +743,9 @@ static void test_mocs_suspend_resume(device_t device, enum igt_suspend_state s_s
 		igt_debug("Running on GT%d\n", gt);
 
 		sprintf(path, "gt%d/mocs", gt);
-		igt_assert(igt_debugfs_exists(device.fd_xe, path, O_RDONLY));
+		igt_require_f(igt_debugfs_exists(device.fd_xe, path, O_RDONLY),
+			      "Failed to open required debugfs entry: %s\n", path);
+
 		igt_debugfs_dump(device.fd_xe, path);
 		igt_debugfs_read(device.fd_xe, path, mocs_content_pre);
 
