@@ -36,6 +36,7 @@
 #include "igt.h"
 #include "igt_aux.h"
 #include "igt_psr.h"
+#include "igt_vec.h"
 #include <sys/ioctl.h>
 #include <sys/time.h>
 #include <poll.h>
@@ -45,7 +46,7 @@
  * Description: Verify the async flip functionality and the fps during async flips
  *              Alternate between sync and async flips
  *
- * SUBTEST: async-flip-with-page-flip-events
+ * SUBTEST: async-flip-with-page-flip-events-tiled
  * Description: Verify the async flip functionality and the fps during async flips
  *              Wait for page flip events in between successive asynchronous flips
  *
@@ -66,7 +67,7 @@
  * SUBTEST: alternate-sync-async-flip-atomic
  * Description: Verify the async flip functionality and the fps during async flips using atomic path
  *
- * SUBTEST: async-flip-with-page-flip-events-atomic
+ * SUBTEST: async-flip-with-page-flip-events-tiled-atomic
  * Description: Wait for page flip events in between successive asynchronous flips using atomic path
  *
  * SUBTEST: test-time-stamp-atomic
@@ -85,6 +86,21 @@
  *
  * SUBTEST: async-flip-suspend-resume
  * Description: Verify the async flip functionality with suspend and resume cycle
+ *
+ * SUBTEST: overlay-atomic
+ * Description: Verify overlay planes with async flips in atomic API
+ *
+ * SUBTEST: async-flip-with-page-flip-events-linear
+ * Description: Verify the async flip functionality and the fps during async flips
+ *		with linear modifier
+ *
+ * SUBTEST: async-flip-with-page-flip-events-linear-atomic
+ * Description: Verify the async flip functionality and the fps during async flips
+ *		with linear modifier in Atomic API
+ *
+ * SUBTEST: basic-modeset-with-all-modifiers-formats
+ * Description: Verify the basic sanity check of async flip functionality with
+ *		all supported modifiers and formats
  */
 
 #define CURSOR_POS 128
@@ -105,12 +121,14 @@ typedef struct {
 	uint32_t crtc_id;
 	uint32_t refresh_rate;
 	struct igt_fb bufs[NUM_FBS];
+	struct igt_fb bufs_overlay[NUM_FBS];
 	igt_display_t display;
 	igt_output_t *output;
 	unsigned long flip_timestamp_us;
 	double flip_interval;
 	uint64_t modifier;
 	igt_plane_t *plane;
+	igt_plane_t *plane_overlay;
 	igt_pipe_crc_t *pipe_crc;
 	igt_crc_t ref_crc;
 	int flip_count;
@@ -119,11 +137,19 @@ typedef struct {
 	enum pipe pipe;
 	bool alternate_sync_async;
 	bool suspend_resume;
-	bool allow_fail;
 	struct buf_ops *bops;
 	bool atomic_path;
+	bool overlay_path;
+	bool linear_modifier;
+	unsigned int plane_format;
+	bool async_mod_formats;
 } data_t;
 
+struct format_mod {
+	uint64_t modifier;
+	uint32_t format;
+};
+
 static void flip_handler(int fd_, unsigned int sequence, unsigned int tv_sec,
 			 unsigned int tv_usec, void *_data)
 {
@@ -179,6 +205,9 @@ static void wait_flip_event(data_t *data)
 static uint64_t default_modifier(data_t *data)
 {
 	if (igt_display_has_format_mod(&data->display, DRM_FORMAT_XRGB8888,
+				       I915_FORMAT_MOD_4_TILED))
+		return I915_FORMAT_MOD_4_TILED;
+	else if (igt_display_has_format_mod(&data->display, DRM_FORMAT_XRGB8888,
 				       I915_FORMAT_MOD_X_TILED))
 		return I915_FORMAT_MOD_X_TILED;
 	else
@@ -193,7 +222,7 @@ static void make_fb(data_t *data, struct igt_fb *fb,
 
 	rec_width = width / (NUM_FBS * 2);
 
-	igt_create_color_fb(data->drm_fd, width, height, DRM_FORMAT_XRGB8888,
+	igt_create_color_fb(data->drm_fd, width, height, data->plane_format,
 			    data->modifier, 0.0, 0.0, 0.5, fb);
 
 	cr = igt_get_cairo_ctx(data->drm_fd, fb);
@@ -203,8 +232,37 @@ static void make_fb(data_t *data, struct igt_fb *fb,
 
 static void require_monotonic_timestamp(int fd)
 {
-	igt_require_f(igt_has_drm_cap(fd, DRM_CAP_TIMESTAMP_MONOTONIC),
-		      "Monotonic timestamps not supported\n");
+	int ret = igt_has_drm_cap(fd, DRM_CAP_TIMESTAMP_MONOTONIC);
+
+	igt_require_f(ret >= 0, "Monotonic timestamps cap doesn't exist in this kernel\n");
+	igt_require_f(ret == 1, "Monotonic timestamps not supported\n");
+}
+
+static void require_atomic_async_cap(data_t *data)
+{
+	int ret = igt_has_drm_cap(data->drm_fd, DRM_CAP_ATOMIC_ASYNC_PAGE_FLIP);
+
+	igt_require_f(ret >= 0, "Atomic async flip cap doesn't exist in this kernel\n");
+	igt_require_f(ret == 1, "Atomic async flip not supported by this driver\n");
+}
+
+static void require_overlay_flip_support(data_t *data)
+{
+	struct igt_fb *bufs = data->bufs_overlay;
+	igt_plane_t *plane = data->plane_overlay;
+	int flags = DRM_MODE_PAGE_FLIP_EVENT;
+
+	igt_plane_set_fb(plane, &bufs[0]);
+
+	igt_require_f(!igt_display_try_commit_atomic(&data->display, flags, data),
+		      "Overlay planes not supported\n");
+
+	flags |= DRM_MODE_PAGE_FLIP_ASYNC;
+
+	igt_plane_set_fb(plane, &bufs[1]);
+
+	igt_require_f(!igt_display_try_commit_atomic(&data->display, flags, data),
+		      "Async flip for overlay planes not supported\n");
 }
 
 static void test_init(data_t *data)
@@ -222,6 +280,16 @@ static void test_init(data_t *data)
 	igt_output_set_pipe(data->output, data->pipe);
 
 	data->plane = igt_output_get_plane_type(data->output, DRM_PLANE_TYPE_PRIMARY);
+	if (data->overlay_path)
+		data->plane_overlay = igt_output_get_plane_type(data->output, DRM_PLANE_TYPE_OVERLAY);
+}
+
+static void test_init_ops(data_t *data)
+{
+	data->alternate_sync_async = false;
+	data->atomic_path = false;
+	data->overlay_path = false;
+	data->linear_modifier = false;
 }
 
 static void test_init_fbs(data_t *data)
@@ -236,22 +304,40 @@ static void test_init_fbs(data_t *data)
 	width = mode->hdisplay;
 	height = mode->vdisplay;
 
+	/* if the modifier or the output changed, we need to recreate the buffers */
 	if (prev_output_id != data->output->id ||
 	    prev_modifier != data->modifier) {
 		prev_output_id = data->output->id;
 		prev_modifier = data->modifier;
 
-		if (data->bufs[0].fb_id) {
+		if (data->bufs[0].fb_id)
 			for (i = 0; i < NUM_FBS; i++)
 				igt_remove_fb(data->drm_fd, &data->bufs[i]);
-		}
 
+		if (data->bufs_overlay[0].fb_id)
+			for (i = 0; i < NUM_FBS; i++)
+				igt_remove_fb(data->drm_fd, &data->bufs_overlay[i]);
+	}
+
+	if (!data->bufs[0].fb_id)
 		for (i = 0; i < NUM_FBS; i++)
 			make_fb(data, &data->bufs[i], width, height, i);
-	}
 
 	igt_plane_set_fb(data->plane, &data->bufs[0]);
 	igt_plane_set_size(data->plane, width, height);
+
+	if (!data->bufs_overlay[0].fb_id && data->overlay_path) {
+		for (i = 0; i < NUM_FBS; i++)
+			make_fb(data, &data->bufs_overlay[i], width, height, i);
+
+		igt_plane_set_fb(data->plane_overlay, &data->bufs_overlay[0]);
+		igt_plane_set_size(data->plane_overlay, width, height);
+	}
+
+	/* remove unused buffers */
+	if (data->bufs_overlay[0].fb_id && !data->overlay_path)
+		for (i = 0; i < NUM_FBS; i++)
+			igt_remove_fb(data->drm_fd, &data->bufs_overlay[i]);
 }
 
 static bool async_flip_needs_extra_frame(data_t *data)
@@ -279,12 +365,17 @@ static bool async_flip_needs_extra_frame(data_t *data)
 static int perform_flip(data_t *data, int frame, int flags)
 {
 	int ret;
+	igt_plane_t *plane;
+	struct igt_fb *bufs;
+
+	plane = data->overlay_path ? data->plane_overlay : data->plane;
+	bufs = data->overlay_path ? data->bufs_overlay : data->bufs;
 
 	if (!data->atomic_path) {
 		ret = drmModePageFlip(data->drm_fd, data->crtc_id,
-				      data->bufs[frame % NUM_FBS].fb_id, flags, data);
+				     bufs[frame % NUM_FBS].fb_id, flags, data);
 	} else {
-		igt_plane_set_fb(data->plane, &data->bufs[frame % NUM_FBS]);
+		igt_plane_set_fb(plane, &bufs[frame % NUM_FBS]);
 		ret = igt_display_try_commit_atomic(&data->display, flags, data);
 	}
 
@@ -300,6 +391,9 @@ static void test_async_flip(data_t *data)
 
 	igt_display_commit2(&data->display, data->display.is_atomic ? COMMIT_ATOMIC : COMMIT_LEGACY);
 
+	if (data->overlay_path)
+		require_overlay_flip_support(data);
+
 	gettimeofday(&start, NULL);
 	frame = 1;
 	do {
@@ -325,9 +419,23 @@ static void test_async_flip(data_t *data)
 			}
 		}
 
+		if (data->async_mod_formats) {
+			if (async_flip_needs_extra_frame(data)) {
+				ret = perform_flip(data, frame, flags);
+				igt_assert_eq(ret, 0);
+
+				wait_flip_event(data);
+			}
+		}
+
 		ret = perform_flip(data, frame, flags);
 
-		if (frame == 1 && data->allow_fail)
+		/* AMD cannot perform async page flip if fb mem type changes,
+		 * and this condition cannot be controlled by any userspace
+		 * configuration. Therefore allow EINVAL failure and skip the
+		 * test for AMD devices.
+		 */
+		if (is_amdgpu_device(data->drm_fd))
 			igt_skip_on(ret == -EINVAL);
 		else
 			igt_assert_eq(ret, 0);
@@ -348,10 +456,24 @@ static void test_async_flip(data_t *data)
 			data->suspend_resume = false;
 			igt_system_suspend_autoresume(SUSPEND_STATE_MEM, SUSPEND_TEST_NONE);
 		}
+
+		/*
+		 * Temporarily Reduce test execution for all formats and modifiers.
+		 *
+		 * TODO: Extend support for full execution for all formats and modifiers,
+		 * possibly controlled via an extended flag
+		 */
+		if (data->async_mod_formats) {
+			igt_assert_f(ret == 0, "Async flip failed with %s modifier and %s format",
+				     igt_fb_modifier_name(data->modifier),
+				     igt_format_str(data->plane_format));
+			break;
+		}
+
 		frame++;
 	} while (diff.tv_sec < RUN_TIME);
 
-	if (!data->alternate_sync_async) {
+	if (!data->alternate_sync_async && !data->async_mod_formats) {
 		fps = frame * 1000 / RUN_TIME;
 		igt_assert_f((fps / 1000) > (data->refresh_rate * MIN_FLIPS_PER_FRAME),
 			     "FPS should be significantly higher than the refresh rate\n");
@@ -683,10 +805,30 @@ static void test_crc(data_t *data)
 	igt_assert_lt(data->frame_count * 2, data->flip_count);
 }
 
+static void require_linear_modifier(data_t *data)
+{
+	if(!igt_plane_has_prop(data->plane, IGT_PLANE_IN_FORMATS_ASYNC)) {
+		data->modifier = DRM_FORMAT_MOD_LINEAR;
+		return;
+	}
+
+	for (int i = 0; i < data->plane->async_format_mod_count; i++) {
+		if (data->plane->async_modifiers[i] == DRM_FORMAT_MOD_LINEAR) {
+			data->modifier = DRM_FORMAT_MOD_LINEAR;
+			return;
+		}
+	}
+
+	igt_skip("Linear modifier not supported for async flips on this platform\n");
+}
+
 static void run_test(data_t *data, void (*test)(data_t *))
 {
 	igt_display_t *display = &data->display;
 
+	if (data->atomic_path)
+		require_atomic_async_cap(data);
+
 	for_each_pipe_with_valid_output(display, data->pipe, data->output) {
 		igt_display_reset(display);
 
@@ -695,8 +837,12 @@ static void run_test(data_t *data, void (*test)(data_t *))
 			continue;
 
 		test_init(data);
-		data->allow_fail = false;
-		data->modifier = default_modifier(data);
+
+		if (data->linear_modifier)
+			require_linear_modifier(data);
+		else
+			data->modifier = default_modifier(data);
+
 		igt_dynamic_f("pipe-%s-%s", kmstest_pipe_name(data->pipe), data->output->name) {
 			/*
 			 * FIXME: joiner+async flip is busted currently in KMD.
@@ -710,21 +856,112 @@ static void run_test(data_t *data, void (*test)(data_t *))
 	}
 }
 
-static void run_test_with_modifiers(data_t *data, void (*test)(data_t *))
+static bool skip_async_format_mod(data_t *data,
+			    uint32_t format, uint64_t modifier,
+			    struct igt_vec *tested_formats)
 {
+	/* test each format "class" only once in non-extended tests */
+	struct format_mod rf = {
+		.format = igt_reduce_format(format),
+		.modifier = modifier,
+	};
+
+	/* igt doesn't know how to sw generate UBWC: */
+	if (is_msm_device(data->drm_fd) &&
+	    modifier == DRM_FORMAT_MOD_QCOM_COMPRESSED)
+		return true;
+
+	/* VEBOX just hangs with an actual 10bpc format */
+	if (igt_fb_is_gen12_mc_ccs_modifier(modifier) &&
+	    igt_reduce_format(format) == DRM_FORMAT_XRGB2101010)
+		return true;
+
+	if (igt_vec_index(tested_formats, &rf) >= 0)
+		return true;
+
+	igt_vec_push(tested_formats, &rf);
+
+	return false;
+}
+
+static void run_test_with_async_format_modifiers(data_t *data, void (*test)(data_t *))
+{
+	struct igt_vec tested_formats;
+
+	igt_vec_init(&tested_formats, sizeof(struct format_mod));
+
 	for_each_pipe_with_valid_output(&data->display, data->pipe, data->output) {
 		test_init(data);
 
-		for (int i = 0; i < data->plane->format_mod_count; i++) {
+		igt_assert_f(data->plane->async_format_mod_count > 0,
+			     "No async format/modifier supported\n");
+
+		for (int i = 0; i < data->plane->async_format_mod_count; i++) {
+			struct format_mod f = {
+				.format = data->plane->async_formats[i],
+				.modifier = data->plane->async_modifiers[i],
+			};
+
+			if (skip_async_format_mod(data, f.format, f.modifier, &tested_formats)) {
+				igt_debug("Skipping format " IGT_FORMAT_FMT " / modifier "
+					   IGT_MODIFIER_FMT " on %s.%u\n",
+					   IGT_FORMAT_ARGS(f.format),
+					   IGT_MODIFIER_ARGS(f.modifier),
+					   kmstest_pipe_name(data->pipe),
+					   data->plane->index);
+				continue;
+			}
+
+			data->modifier = f.modifier;
+			data->plane_format = f.format;
+			data->async_mod_formats = true;
+
+			igt_dynamic_f("pipe-%s-%s-%s-%s", kmstest_pipe_name(data->pipe),
+				      data->output->name,
+				      igt_fb_modifier_name(data->modifier),
+				      igt_format_str(data->plane_format)) {
+				      /*
+				       * FIXME: joiner+async flip is busted currently in KMD.
+				       * Remove this check once the issues are fixed in KMD.
+				       */
+				      igt_skip_on_f(is_joiner_mode(data->drm_fd,
+								   data->output),
+						    "Skipping, async flip not supported "
+						    "on joiner mode\n");
+				      test_init_fbs(data);
+				      test(data);
+			}
+		}
+	}
+
+	igt_vec_fini(&tested_formats);
+}
+
+static void run_test_with_modifiers(data_t *data, void (*test)(data_t *))
+{
+	if (data->atomic_path)
+		require_atomic_async_cap(data);
+
+	for_each_pipe_with_valid_output(&data->display, data->pipe, data->output) {
+		test_init(data);
+
+		igt_require_f(data->plane->async_format_mod_count > 0,
+			     "No async format/modifier supported\n");
+
+		for (int i = 0; i < data->plane->async_format_mod_count; i++) {
+			uint64_t modifier = data->plane->async_modifiers[i];
+
 			if (data->plane->formats[i] != DRM_FORMAT_XRGB8888)
 				continue;
 
-			data->allow_fail = true;
-			data->modifier = data->plane->modifiers[i];
+			if (modifier == DRM_FORMAT_MOD_LINEAR)
+				continue;
+
+			data->modifier = modifier;
 
 			igt_dynamic_f("pipe-%s-%s-%s", kmstest_pipe_name(data->pipe),
 				      data->output->name,
-				      igt_fb_modifier_name(data->modifier)) {
+				      igt_fb_modifier_name(modifier)) {
 				      /*
 				       * FIXME: joiner+async flip is busted currently in KMD.
 				       * Remove this check once the issues are fixed in KMD.
@@ -747,16 +984,20 @@ igt_main
 	int i;
 
 	igt_fixture {
+		int ret;
+
 		data.drm_fd = drm_open_driver_master(DRIVER_ANY);
 		kmstest_set_vt_graphics_mode();
 		igt_display_require(&data.display, data.drm_fd);
 		igt_display_require_output(&data.display);
 
-		igt_require_f(igt_has_drm_cap(data.drm_fd, DRM_CAP_ASYNC_PAGE_FLIP),
-			      "Async Flip is not supported\n");
+		ret = igt_has_drm_cap(data.drm_fd, DRM_CAP_ASYNC_PAGE_FLIP);
+		igt_require_f(ret >= 0, "Async page flip cap doesn't exist in this kernel\n");
+		igt_require_f(ret == 1, "Async page flip is not supported\n");
 
 		if (is_intel_device(data.drm_fd))
 			data.bops = buf_ops_create(data.drm_fd);
+		data.plane_format = DRM_FORMAT_XRGB8888;
 	}
 
 	igt_describe("Verify the async flip functionality and the fps during async flips");
@@ -765,50 +1006,72 @@ igt_main
 			require_monotonic_timestamp(data.drm_fd);
 
 		igt_describe("Wait for page flip events in between successive asynchronous flips");
-		igt_subtest_with_dynamic("async-flip-with-page-flip-events") {
-			data.alternate_sync_async = false;
-			data.atomic_path = false;
-			if (is_intel_device(data.drm_fd))
-				run_test_with_modifiers(&data, test_async_flip);
-			else
-				run_test(&data, test_async_flip);
+		igt_subtest_with_dynamic("async-flip-with-page-flip-events-tiled") {
+			test_init_ops(&data);
+			igt_require(is_intel_device(data.drm_fd));
+			run_test_with_modifiers(&data, test_async_flip);
 		}
 
 		igt_describe("Wait for page flip events in between successive "
 			     "asynchronous flips using atomic path");
-		igt_subtest_with_dynamic("async-flip-with-page-flip-events-atomic") {
-			data.alternate_sync_async = false;
+		igt_subtest_with_dynamic("async-flip-with-page-flip-events-tiled-atomic") {
+			test_init_ops(&data);
 			data.atomic_path = true;
-			if (is_intel_device(data.drm_fd))
-				run_test_with_modifiers(&data, test_async_flip);
-			else
-				run_test(&data, test_async_flip);
+			igt_require(is_intel_device(data.drm_fd));
+			run_test_with_modifiers(&data, test_async_flip);
+		}
+
+		igt_describe("Wait for page flip events in between successive asynchronous "
+			     "flips with linear modifiers");
+		igt_subtest_with_dynamic("async-flip-with-page-flip-events-linear") {
+			test_init_ops(&data);
+			data.linear_modifier = true;
+			run_test(&data, test_async_flip);
+		}
+
+		igt_describe("Wait for page flip events in between successive asynchronous "
+			     "flips using atomic path with linear modifiers");
+		igt_subtest_with_dynamic("async-flip-with-page-flip-events-linear-atomic") {
+			test_init_ops(&data);
+			data.linear_modifier = true;
+			run_test(&data, test_async_flip);
 		}
 
 		igt_describe("Alternate between sync and async flips");
 		igt_subtest_with_dynamic("alternate-sync-async-flip") {
+			test_init_ops(&data);
 			data.alternate_sync_async = true;
-			data.atomic_path = false;
 			run_test(&data, test_async_flip);
 		}
 
 		igt_describe("Alternate between sync and async flips using atomic path");
 		igt_subtest_with_dynamic("alternate-sync-async-flip-atomic") {
+			test_init_ops(&data);
 			data.alternate_sync_async = true;
 			data.atomic_path = true;
 			run_test(&data, test_async_flip);
 		}
 
+		igt_describe("Verify overlay planes with async flips in atomic API");
+		igt_subtest_with_dynamic("overlay-atomic") {
+			test_init_ops(&data);
+			igt_require(is_amdgpu_device(data.drm_fd));
+			data.atomic_path = true;
+			data.overlay_path = true;
+			run_test(&data, test_async_flip);
+		}
+
 		igt_describe("Verify that the async flip timestamp does not "
 			     "coincide with either previous or next vblank");
 		igt_subtest_with_dynamic("test-time-stamp") {
-			data.atomic_path = false;
+			test_init_ops(&data);
 			run_test(&data, test_timestamp);
 		}
 
 		igt_describe("Verify that the async flip timestamp does not coincide "
 			     "with either previous or next vblank with atomic path");
 		igt_subtest_with_dynamic("test-time-stamp-atomic") {
+			test_init_ops(&data);
 			data.atomic_path = true;
 			run_test(&data, test_timestamp);
 		}
@@ -816,6 +1079,7 @@ igt_main
 
 	igt_describe("Verify that the DRM_IOCTL_MODE_CURSOR passes after async flip");
 	igt_subtest_with_dynamic("test-cursor") {
+		test_init_ops(&data);
 		/*
 		 * Intel's PSR2 selective fetch adds other planes to state when
 		 * necessary, causing the async flip to fail because async flip is not
@@ -825,13 +1089,13 @@ igt_main
 			      "PSR2 sel fetch causes cursor to be added to primary plane "
 			      "pages flips and async flip is not supported in cursor\n");
 
-		data.atomic_path = false;
 		run_test(&data, test_cursor);
 	}
 
 	igt_describe("Verify that the DRM_IOCTL_MODE_CURSOR passes after "
 		     "async flip with atomic commit");
 	igt_subtest_with_dynamic("test-cursor-atomic") {
+		test_init_ops(&data);
 		/*
 		 * Intel's PSR2 selective fetch adds other planes to state when
 		 * necessary, causing the async flip to fail because async flip is not
@@ -846,6 +1110,7 @@ igt_main
 
 	igt_describe("Negative case to verify if changes in fb are rejected from kernel as expected");
 	igt_subtest_with_dynamic("invalid-async-flip") {
+		test_init_ops(&data);
 		/* TODO: support more vendors */
 		igt_require(is_intel_device(data.drm_fd));
 		igt_require(igt_display_has_format_mod(&data.display, DRM_FORMAT_XRGB8888,
@@ -853,13 +1118,13 @@ igt_main
 		igt_require(igt_display_has_format_mod(&data.display, DRM_FORMAT_XRGB8888,
 						       I915_FORMAT_MOD_Y_TILED));
 
-		data.atomic_path = false;
 		run_test(&data, test_invalid);
 	}
 
 	igt_describe("Negative case to verify if changes in fb are rejected "
 		     "from kernel as expected when async flip is done using atomic path");
 	igt_subtest_with_dynamic("invalid-async-flip-atomic") {
+		test_init_ops(&data);
 		data.atomic_path = true;
 		/* TODO: support more vendors */
 		igt_require(is_intel_device(data.drm_fd));
@@ -873,16 +1138,17 @@ igt_main
 
 	igt_describe("Use CRC to verify async flip scans out the correct framebuffer");
 	igt_subtest_with_dynamic("crc") {
+		test_init_ops(&data);
 		/* Devices without CRC can't run this test */
 		igt_require_pipe_crc(data.drm_fd);
 
-		data.atomic_path = false;
 		run_test(&data, test_crc);
 	}
 
 	igt_describe("Use CRC to verify async flip scans out the correct framebuffer "
 		     "with atomic commit");
 	igt_subtest_with_dynamic("crc-atomic") {
+		test_init_ops(&data);
 		/* Devices without CRC can't run this test */
 		igt_require_pipe_crc(data.drm_fd);
 
@@ -892,13 +1158,21 @@ igt_main
 
 	igt_describe("Verify the async flip functionality after suspend and resume cycle");
 	igt_subtest_with_dynamic("async-flip-suspend-resume") {
+		test_init_ops(&data);
 		data.suspend_resume = true;
 		run_test(&data, test_async_flip);
 	}
 
+	igt_describe("Verify basic modeset with all supported modifier and format combinations");
+	igt_subtest_with_dynamic("basic-modeset-with-all-modifiers-formats") {
+		run_test_with_async_format_modifiers(&data, test_async_flip);
+	}
+
 	igt_fixture {
-		for (i = 0; i < NUM_FBS; i++)
+		for (i = 0; i < NUM_FBS; i++) {
 			igt_remove_fb(data.drm_fd, &data.bufs[i]);
+			igt_remove_fb(data.drm_fd, &data.bufs_overlay[i]);
+		}
 
 		if (is_intel_device(data.drm_fd))
 			buf_ops_destroy(data.bops);
